
module Make

# 55 "asllib/Parser.mly"
          (Config : ParserConfig.CONFIG)
# 7 "asllib/Parser.ml"

= struct
  
  module MenhirBasics = struct
    
    exception Error
    
    let _eRR =
      fun _s ->
        raise Error
    
    type token = Tokens.token
    
  end
  
  include MenhirBasics
  
# 63 "asllib/Parser.mly"
  

open AST
open ASTUtils
open Desugar

let version = V1
let t_bit ~loc = T_Bits (E_Literal (L_Int Z.one) |> add_pos_from loc, [])
let zero ~loc = E_Literal (L_Int Z.zero) |> add_pos_from loc

let make_ldi_vars (xs, ty) =
  let make_one x =
    S_Decl (LDK_Var, LDI_Var x.desc, Some ty, None) |> add_pos_from x
  in
  List.map make_one xs |> stmt_from_list |> desc

let make_ty_decl_subtype (x, s) =
  let name, _fields = s.desc in
  let ty = ASTUtils.add_pos_from s (T_Named name) in
  D_TypeDecl (x, ty, Some s.desc)

let prec =
  let open AST in
  function
  | `BOR | `BAND | `IMPL | `BEQ -> 1
  | `EQ_OP | `NEQ -> 2
  | `PLUS | `MINUS | `OR | `XOR | `AND | `CONCAT -> 3
  | `MUL | `DIV | `DIVRM | `RDIV | `MOD | `SHL | `SHR -> 4
  | `POW -> 5
  | `GT | `GEQ | `LT | `LEQ -> 0 (* Non assoc *)

let check_not_same_prec loc op op' =
  if prec op = prec op' then Error.(fatal_from loc CannotParse)

let check_not_binop_same_prec op e =
  match e.desc with
  | E_Binop (op', _, _) when op != op' -> check_not_same_prec e op op'
  | _ -> ()

let e_binop (e1, op, e2) =
  let () = check_not_binop_same_prec op e1
  and () = check_not_binop_same_prec op e2
  in
  E_Binop (op, e1, e2)

let e_call call = E_Call { call with call_type = ST_Function }
let s_call call = S_Call { call with call_type = ST_Procedure }

let le_var x = LE_Var x.desc |> add_pos_from x


# 77 "asllib/Parser.ml"
  
  type ('s, 'r) _menhir_state = 
    | MenhirState000 : ('s, _menhir_box_opn) _menhir_state
      (** State 000.
        Stack shape : .
        Start symbol: opn. *)

    | MenhirState001 : (('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_state
      (** State 001.
        Stack shape : WHILE.
        Start symbol: <undetermined>. *)

    | MenhirState004 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 004.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState005 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 005.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState006 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 006.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState008 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 008.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState009 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 009.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState010 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 010.
        Stack shape : IDENTIFIER LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState012 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 012.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState015 : (('s, 'r) _menhir_cell1_ARBITRARY _menhir_cell0_COLON, 'r) _menhir_state
      (** State 015.
        Stack shape : ARBITRARY COLON.
        Start symbol: <undetermined>. *)

    | MenhirState018 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 018.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState019 : (('s, 'r) _menhir_cell1_INTEGER, 'r) _menhir_state
      (** State 019.
        Stack shape : INTEGER.
        Start symbol: <undetermined>. *)

    | MenhirState020 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 020.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState021 : ((('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 021.
        Stack shape : LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState024 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 024.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState025 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 025.
        Stack shape : expr LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState026 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 026.
        Stack shape : expr LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState027 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_XOR, 'r) _menhir_state
      (** State 027.
        Stack shape : expr XOR.
        Start symbol: <undetermined>. *)

    | MenhirState028 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_XOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 028.
        Stack shape : expr XOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState029 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_state
      (** State 029.
        Stack shape : expr SHR.
        Start symbol: <undetermined>. *)

    | MenhirState030 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 030.
        Stack shape : expr SHR expr.
        Start symbol: <undetermined>. *)

    | MenhirState031 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_state
      (** State 031.
        Stack shape : expr POW.
        Start symbol: <undetermined>. *)

    | MenhirState032 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 032.
        Stack shape : expr POW expr.
        Start symbol: <undetermined>. *)

    | MenhirState033 : (('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 033.
        Stack shape : LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState034 : (('s, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 034.
        Stack shape : COLON.
        Start symbol: <undetermined>. *)

    | MenhirState035 : ((('s, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 035.
        Stack shape : COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState036 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_state
      (** State 036.
        Stack shape : expr SHL.
        Start symbol: <undetermined>. *)

    | MenhirState037 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 037.
        Stack shape : expr SHL expr.
        Start symbol: <undetermined>. *)

    | MenhirState038 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IN, 'r) _menhir_state
      (** State 038.
        Stack shape : expr IN.
        Start symbol: <undetermined>. *)

    | MenhirState039 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 039.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState040 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 040.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState041 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 041.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState043 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 043.
        Stack shape : expr DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState045 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 045.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState052 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 052.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState053 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 053.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState055 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 055.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState056 : (('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 056.
        Stack shape : LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState057 : ((('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 057.
        Stack shape : LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState058 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_state
      (** State 058.
        Stack shape : expr RDIV.
        Start symbol: <undetermined>. *)

    | MenhirState059 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 059.
        Stack shape : expr RDIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState060 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_state
      (** State 060.
        Stack shape : expr PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState061 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 061.
        Stack shape : expr PLUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState062 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_state
      (** State 062.
        Stack shape : expr MUL.
        Start symbol: <undetermined>. *)

    | MenhirState063 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 063.
        Stack shape : expr MUL expr.
        Start symbol: <undetermined>. *)

    | MenhirState064 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_state
      (** State 064.
        Stack shape : expr MOD.
        Start symbol: <undetermined>. *)

    | MenhirState065 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 065.
        Stack shape : expr MOD expr.
        Start symbol: <undetermined>. *)

    | MenhirState066 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_state
      (** State 066.
        Stack shape : expr DIVRM.
        Start symbol: <undetermined>. *)

    | MenhirState067 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 067.
        Stack shape : expr DIVRM expr.
        Start symbol: <undetermined>. *)

    | MenhirState068 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_state
      (** State 068.
        Stack shape : expr DIV.
        Start symbol: <undetermined>. *)

    | MenhirState069 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 069.
        Stack shape : expr DIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState070 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_state
      (** State 070.
        Stack shape : expr OR.
        Start symbol: <undetermined>. *)

    | MenhirState071 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 071.
        Stack shape : expr OR expr.
        Start symbol: <undetermined>. *)

    | MenhirState072 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_state
      (** State 072.
        Stack shape : expr NEQ.
        Start symbol: <undetermined>. *)

    | MenhirState074 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 074.
        Stack shape : expr NEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState075 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 075.
        Stack shape : expr MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState076 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 076.
        Stack shape : expr MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState077 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_state
      (** State 077.
        Stack shape : expr LT.
        Start symbol: <undetermined>. *)

    | MenhirState078 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 078.
        Stack shape : expr LT expr.
        Start symbol: <undetermined>. *)

    | MenhirState079 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_state
      (** State 079.
        Stack shape : expr COLON_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState080 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 080.
        Stack shape : expr COLON_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState081 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_state
      (** State 081.
        Stack shape : expr AND.
        Start symbol: <undetermined>. *)

    | MenhirState082 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 082.
        Stack shape : expr AND expr.
        Start symbol: <undetermined>. *)

    | MenhirState083 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 083.
        Stack shape : expr LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState084 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 084.
        Stack shape : expr LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState085 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_state
      (** State 085.
        Stack shape : expr GT.
        Start symbol: <undetermined>. *)

    | MenhirState086 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 086.
        Stack shape : expr GT expr.
        Start symbol: <undetermined>. *)

    | MenhirState087 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 087.
        Stack shape : expr GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState088 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 088.
        Stack shape : expr GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState089 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_state
      (** State 089.
        Stack shape : expr IMPL.
        Start symbol: <undetermined>. *)

    | MenhirState090 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 090.
        Stack shape : expr IMPL expr.
        Start symbol: <undetermined>. *)

    | MenhirState091 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_state
      (** State 091.
        Stack shape : expr EQ_OP.
        Start symbol: <undetermined>. *)

    | MenhirState093 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 093.
        Stack shape : expr EQ_OP expr.
        Start symbol: <undetermined>. *)

    | MenhirState094 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_state
      (** State 094.
        Stack shape : expr BOR.
        Start symbol: <undetermined>. *)

    | MenhirState095 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 095.
        Stack shape : expr BOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState096 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_state
      (** State 096.
        Stack shape : expr BEQ.
        Start symbol: <undetermined>. *)

    | MenhirState097 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 097.
        Stack shape : expr BEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState098 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_state
      (** State 098.
        Stack shape : expr BAND.
        Start symbol: <undetermined>. *)

    | MenhirState099 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 099.
        Stack shape : expr BAND expr.
        Start symbol: <undetermined>. *)

    | MenhirState100 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AS, 'r) _menhir_state
      (** State 100.
        Stack shape : expr AS.
        Start symbol: <undetermined>. *)

    | MenhirState104 : (('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 104.
        Stack shape : BITS LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState105 : ((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 105.
        Stack shape : BITS LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState106 : (((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR, 'r) _menhir_state
      (** State 106.
        Stack shape : BITS LPAR expr RPAR.
        Start symbol: <undetermined>. *)

    | MenhirState107 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 107.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState112 : (('s, 'r) _menhir_cell1_slices _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 112.
        Stack shape : slices IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState113 : (('s, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 113.
        Stack shape : COLON.
        Start symbol: <undetermined>. *)

    | MenhirState116 : (('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_state
      (** State 116.
        Stack shape : ARRAY.
        Start symbol: <undetermined>. *)

    | MenhirState117 : ((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 117.
        Stack shape : ARRAY expr.
        Start symbol: <undetermined>. *)

    | MenhirState119 : (((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RRBRACKET, 'r) _menhir_state
      (** State 119.
        Stack shape : ARRAY expr RRBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState125 : (('s, 'r) _menhir_cell1_bitfield, 'r) _menhir_state
      (** State 125.
        Stack shape : bitfield.
        Start symbol: <undetermined>. *)

    | MenhirState131 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 131.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState132 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 132.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState133 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 133.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState134 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 134.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState135 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 135.
        Stack shape : expr THEN expr ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState136 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 136.
        Stack shape : expr THEN expr ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState137 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 137.
        Stack shape : expr THEN expr ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState138 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 138.
        Stack shape : expr THEN expr ELSIF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState139 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 139.
        Stack shape : expr THEN expr ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState140 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 140.
        Stack shape : expr THEN expr ELSE expr.
        Start symbol: <undetermined>. *)

    | MenhirState143 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 143.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState144 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 144.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState145 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 145.
        Stack shape : IDENTIFIER LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState147 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 147.
        Stack shape : IDENTIFIER LBRACE IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState148 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 148.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState149 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 149.
        Stack shape : IDENTIFIER LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState152 : (('s, 'r) _menhir_cell1_field_assign, 'r) _menhir_state
      (** State 152.
        Stack shape : field_assign.
        Start symbol: <undetermined>. *)

    | MenhirState153 : ((('s, 'r) _menhir_cell1_field_assign, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 153.
        Stack shape : field_assign IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState154 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 154.
        Stack shape : IDENTIFIER EQ.
        Start symbol: <undetermined>. *)

    | MenhirState155 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 155.
        Stack shape : IDENTIFIER EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState157 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 157.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState158 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 158.
        Stack shape : expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState164 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 164.
        Stack shape : IDENTIFIER LBRACE clist1(expr) RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState170 : (('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 170.
        Stack shape : GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState171 : ((('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 171.
        Stack shape : GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState172 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 172.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState173 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 173.
        Stack shape : BNOT LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState175 : (('s, 'r) _menhir_cell1_ARBITRARY _menhir_cell0_COLON, 'r) _menhir_state
      (** State 175.
        Stack shape : ARBITRARY COLON.
        Start symbol: <undetermined>. *)

    | MenhirState182 : (('s, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 182.
        Stack shape : pattern.
        Start symbol: <undetermined>. *)

    | MenhirState183 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 183.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState184 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_XOR, 'r) _menhir_state
      (** State 184.
        Stack shape : expr_pattern XOR.
        Start symbol: <undetermined>. *)

    | MenhirState185 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_XOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 185.
        Stack shape : expr_pattern XOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState186 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SLICING, 'r) _menhir_state
      (** State 186.
        Stack shape : expr_pattern SLICING.
        Start symbol: <undetermined>. *)

    | MenhirState187 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 187.
        Stack shape : expr_pattern SLICING expr.
        Start symbol: <undetermined>. *)

    | MenhirState188 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHR, 'r) _menhir_state
      (** State 188.
        Stack shape : expr_pattern SHR.
        Start symbol: <undetermined>. *)

    | MenhirState189 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 189.
        Stack shape : expr_pattern SHR expr.
        Start symbol: <undetermined>. *)

    | MenhirState190 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHL, 'r) _menhir_state
      (** State 190.
        Stack shape : expr_pattern SHL.
        Start symbol: <undetermined>. *)

    | MenhirState191 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 191.
        Stack shape : expr_pattern SHL expr.
        Start symbol: <undetermined>. *)

    | MenhirState192 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_RDIV, 'r) _menhir_state
      (** State 192.
        Stack shape : expr_pattern RDIV.
        Start symbol: <undetermined>. *)

    | MenhirState193 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_RDIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 193.
        Stack shape : expr_pattern RDIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState194 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_POW, 'r) _menhir_state
      (** State 194.
        Stack shape : expr_pattern POW.
        Start symbol: <undetermined>. *)

    | MenhirState195 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_POW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 195.
        Stack shape : expr_pattern POW expr.
        Start symbol: <undetermined>. *)

    | MenhirState196 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_PLUS, 'r) _menhir_state
      (** State 196.
        Stack shape : expr_pattern PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState197 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_PLUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 197.
        Stack shape : expr_pattern PLUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState198 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_OR, 'r) _menhir_state
      (** State 198.
        Stack shape : expr_pattern OR.
        Start symbol: <undetermined>. *)

    | MenhirState199 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_OR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 199.
        Stack shape : expr_pattern OR expr.
        Start symbol: <undetermined>. *)

    | MenhirState200 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_NEQ, 'r) _menhir_state
      (** State 200.
        Stack shape : expr_pattern NEQ.
        Start symbol: <undetermined>. *)

    | MenhirState202 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_NEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 202.
        Stack shape : expr_pattern NEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState203 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MUL, 'r) _menhir_state
      (** State 203.
        Stack shape : expr_pattern MUL.
        Start symbol: <undetermined>. *)

    | MenhirState204 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MUL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 204.
        Stack shape : expr_pattern MUL expr.
        Start symbol: <undetermined>. *)

    | MenhirState205 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MOD, 'r) _menhir_state
      (** State 205.
        Stack shape : expr_pattern MOD.
        Start symbol: <undetermined>. *)

    | MenhirState206 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MOD, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 206.
        Stack shape : expr_pattern MOD expr.
        Start symbol: <undetermined>. *)

    | MenhirState207 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 207.
        Stack shape : expr_pattern MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState208 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 208.
        Stack shape : expr_pattern MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState209 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LT, 'r) _menhir_state
      (** State 209.
        Stack shape : expr_pattern LT.
        Start symbol: <undetermined>. *)

    | MenhirState210 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 210.
        Stack shape : expr_pattern LT expr.
        Start symbol: <undetermined>. *)

    | MenhirState211 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 211.
        Stack shape : expr_pattern LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState212 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 212.
        Stack shape : expr_pattern LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState214 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 214.
        Stack shape : expr_pattern LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState215 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 215.
        Stack shape : expr_pattern LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState216 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IN, 'r) _menhir_state
      (** State 216.
        Stack shape : expr_pattern IN.
        Start symbol: <undetermined>. *)

    | MenhirState217 : ((('s, 'r) _menhir_cell1_IN, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 217.
        Stack shape : IN BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState219 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IMPL, 'r) _menhir_state
      (** State 219.
        Stack shape : expr_pattern IMPL.
        Start symbol: <undetermined>. *)

    | MenhirState220 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IMPL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 220.
        Stack shape : expr_pattern IMPL expr.
        Start symbol: <undetermined>. *)

    | MenhirState221 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GT, 'r) _menhir_state
      (** State 221.
        Stack shape : expr_pattern GT.
        Start symbol: <undetermined>. *)

    | MenhirState222 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 222.
        Stack shape : expr_pattern GT expr.
        Start symbol: <undetermined>. *)

    | MenhirState223 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 223.
        Stack shape : expr_pattern GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState224 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 224.
        Stack shape : expr_pattern GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState225 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_state
      (** State 225.
        Stack shape : expr_pattern EQ_OP.
        Start symbol: <undetermined>. *)

    | MenhirState227 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 227.
        Stack shape : expr_pattern EQ_OP expr.
        Start symbol: <undetermined>. *)

    | MenhirState229 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 229.
        Stack shape : expr_pattern DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState233 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIVRM, 'r) _menhir_state
      (** State 233.
        Stack shape : expr_pattern DIVRM.
        Start symbol: <undetermined>. *)

    | MenhirState234 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIVRM, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 234.
        Stack shape : expr_pattern DIVRM expr.
        Start symbol: <undetermined>. *)

    | MenhirState235 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIV, 'r) _menhir_state
      (** State 235.
        Stack shape : expr_pattern DIV.
        Start symbol: <undetermined>. *)

    | MenhirState236 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 236.
        Stack shape : expr_pattern DIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState237 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_state
      (** State 237.
        Stack shape : expr_pattern COLON_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState238 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 238.
        Stack shape : expr_pattern COLON_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState239 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BOR, 'r) _menhir_state
      (** State 239.
        Stack shape : expr_pattern BOR.
        Start symbol: <undetermined>. *)

    | MenhirState240 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 240.
        Stack shape : expr_pattern BOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState241 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BEQ, 'r) _menhir_state
      (** State 241.
        Stack shape : expr_pattern BEQ.
        Start symbol: <undetermined>. *)

    | MenhirState242 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 242.
        Stack shape : expr_pattern BEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState243 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BAND, 'r) _menhir_state
      (** State 243.
        Stack shape : expr_pattern BAND.
        Start symbol: <undetermined>. *)

    | MenhirState244 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BAND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 244.
        Stack shape : expr_pattern BAND expr.
        Start symbol: <undetermined>. *)

    | MenhirState245 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AS, 'r) _menhir_state
      (** State 245.
        Stack shape : expr_pattern AS.
        Start symbol: <undetermined>. *)

    | MenhirState248 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AND, 'r) _menhir_state
      (** State 248.
        Stack shape : expr_pattern AND.
        Start symbol: <undetermined>. *)

    | MenhirState249 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 249.
        Stack shape : expr_pattern AND expr.
        Start symbol: <undetermined>. *)

    | MenhirState254 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 254.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState256 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 256.
        Stack shape : LPAR pattern.
        Start symbol: <undetermined>. *)

    | MenhirState258 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 258.
        Stack shape : LPAR expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState266 : (('s, 'r) _menhir_cell1_slice, 'r) _menhir_state
      (** State 266.
        Stack shape : slice.
        Start symbol: <undetermined>. *)

    | MenhirState267 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 267.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState268 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_state
      (** State 268.
        Stack shape : expr STAR_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState269 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 269.
        Stack shape : expr STAR_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState270 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_state
      (** State 270.
        Stack shape : expr PLUS_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState271 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 271.
        Stack shape : expr PLUS_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState272 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 272.
        Stack shape : expr COLON.
        Start symbol: <undetermined>. *)

    | MenhirState273 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 273.
        Stack shape : expr COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState279 : (('s, 'r) _menhir_cell1_int_constraint, 'r) _menhir_state
      (** State 279.
        Stack shape : int_constraint.
        Start symbol: <undetermined>. *)

    | MenhirState280 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 280.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState281 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_state
      (** State 281.
        Stack shape : expr SLICING.
        Start symbol: <undetermined>. *)

    | MenhirState282 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 282.
        Stack shape : expr SLICING expr.
        Start symbol: <undetermined>. *)

    | MenhirState289 : (('s, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 289.
        Stack shape : ty.
        Start symbol: <undetermined>. *)

    | MenhirState295 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 295.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState298 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 298.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState299 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 299.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState300 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 300.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState302 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 302.
        Stack shape : LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState304 : (((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 304.
        Stack shape : LPAR expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState308 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 308.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState309 : ((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 309.
        Stack shape : WHILE expr.
        Start symbol: <undetermined>. *)

    | MenhirState310 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_state
      (** State 310.
        Stack shape : expr LOOPLIMIT.
        Start symbol: <undetermined>. *)

    | MenhirState311 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 311.
        Stack shape : expr LOOPLIMIT expr.
        Start symbol: <undetermined>. *)

    | MenhirState313 : (((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_loop_limit, 'r) _menhir_state
      (** State 313.
        Stack shape : WHILE expr loop_limit.
        Start symbol: <undetermined>. *)

    | MenhirState314 : (('s, 'r) _menhir_cell1_VAR, 'r) _menhir_state
      (** State 314.
        Stack shape : VAR.
        Start symbol: <undetermined>. *)

    | MenhirState316 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 316.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState320 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_state
      (** State 320.
        Stack shape : LPAR discard_or_identifier.
        Start symbol: <undetermined>. *)

    | MenhirState322 : ((('s, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_state
      (** State 322.
        Stack shape : discard_or_identifier discard_or_identifier.
        Start symbol: <undetermined>. *)

    | MenhirState328 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 328.
        Stack shape : VAR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState330 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 330.
        Stack shape : IDENTIFIER IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState333 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 333.
        Stack shape : VAR decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState334 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 334.
        Stack shape : VAR decl_item EQ.
        Start symbol: <undetermined>. *)

    | MenhirState335 : ((('s, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 335.
        Stack shape : EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState338 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_state
      (** State 338.
        Stack shape : VAR decl_item as_ty.
        Start symbol: <undetermined>. *)

    | MenhirState339 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 339.
        Stack shape : VAR decl_item as_ty EQ.
        Start symbol: <undetermined>. *)

    | MenhirState340 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 340.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState341 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 341.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState343 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 343.
        Stack shape : IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState346 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 346.
        Stack shape : IDENTIFIER LBRACE COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState349 : ((((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 349.
        Stack shape : IDENTIFIER LBRACE COMMA clist1(expr) RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState356 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_clist2_annotated_IDENTIFIER__, 'r) _menhir_state
      (** State 356.
        Stack shape : VAR clist2(annotated(IDENTIFIER)).
        Start symbol: <undetermined>. *)

    | MenhirState363 : (('s, 'r) _menhir_cell1_TRY, 'r) _menhir_state
      (** State 363.
        Stack shape : TRY.
        Start symbol: <undetermined>. *)

    | MenhirState364 : (('s, 'r) _menhir_cell1_THROW, 'r) _menhir_state
      (** State 364.
        Stack shape : THROW.
        Start symbol: <undetermined>. *)

    | MenhirState366 : ((('s, 'r) _menhir_cell1_THROW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 366.
        Stack shape : THROW expr.
        Start symbol: <undetermined>. *)

    | MenhirState368 : (('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_state
      (** State 368.
        Stack shape : RETURN.
        Start symbol: <undetermined>. *)

    | MenhirState371 : ((('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 371.
        Stack shape : RETURN expr.
        Start symbol: <undetermined>. *)

    | MenhirState372 : (('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_state
      (** State 372.
        Stack shape : REPEAT.
        Start symbol: <undetermined>. *)

    | MenhirState374 : (('s, 'r) _menhir_cell1_PRINTLN _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 374.
        Stack shape : PRINTLN LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState379 : (('s, 'r) _menhir_cell1_PRINT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 379.
        Stack shape : PRINT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState384 : (('s, 'r) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 384.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState390 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 390.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState392 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 392.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState393 : (('s, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 393.
        Stack shape : LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState394 : ((('s, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 394.
        Stack shape : LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState395 : (((('s, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RRBRACKET, 'r) _menhir_state
      (** State 395.
        Stack shape : LLBRACKET expr RRBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState397 : (('s, 'r) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 397.
        Stack shape : DOT IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState400 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_access, 'r) _menhir_state
      (** State 400.
        Stack shape : IDENTIFIER access.
        Start symbol: <undetermined>. *)

    | MenhirState403 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_discard_or_basic_lexpr, 'r) _menhir_state
      (** State 403.
        Stack shape : LPAR discard_or_basic_lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState405 : ((('s, 'r) _menhir_cell1_discard_or_basic_lexpr, 'r) _menhir_cell1_discard_or_basic_lexpr, 'r) _menhir_state
      (** State 405.
        Stack shape : discard_or_basic_lexpr discard_or_basic_lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState412 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 412.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState413 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 413.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState414 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 414.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState415 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 415.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState416 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 416.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState418 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 418.
        Stack shape : IDENTIFIER DOT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState422 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LPAR, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_state
      (** State 422.
        Stack shape : IDENTIFIER DOT LPAR discard_or_field.
        Start symbol: <undetermined>. *)

    | MenhirState424 : ((('s, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_state
      (** State 424.
        Stack shape : discard_or_field discard_or_field.
        Start symbol: <undetermined>. *)

    | MenhirState429 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 429.
        Stack shape : IDENTIFIER DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState431 : ((('s, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 431.
        Stack shape : DOT LBRACKET IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState437 : (('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 437.
        Stack shape : FOR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState438 : ((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 438.
        Stack shape : FOR IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState441 : (((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_state
      (** State 441.
        Stack shape : FOR IDENTIFIER expr direction.
        Start symbol: <undetermined>. *)

    | MenhirState442 : ((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 442.
        Stack shape : FOR IDENTIFIER expr direction expr.
        Start symbol: <undetermined>. *)

    | MenhirState444 : (((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_loop_limit, 'r) _menhir_state
      (** State 444.
        Stack shape : FOR IDENTIFIER expr direction expr loop_limit.
        Start symbol: <undetermined>. *)

    | MenhirState446 : (('s, 'r) _menhir_cell1_DEBUG _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 446.
        Stack shape : DEBUG LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState451 : (('s, 'r) _menhir_cell1_CASE, 'r) _menhir_state
      (** State 451.
        Stack shape : CASE.
        Start symbol: <undetermined>. *)

    | MenhirState452 : ((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 452.
        Stack shape : CASE expr.
        Start symbol: <undetermined>. *)

    | MenhirState453 : (((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_state
      (** State 453.
        Stack shape : CASE expr OF.
        Start symbol: <undetermined>. *)

    | MenhirState454 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 454.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState456 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_state
      (** State 456.
        Stack shape : WHEN pattern_list.
        Start symbol: <undetermined>. *)

    | MenhirState457 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 457.
        Stack shape : WHEN pattern_list expr.
        Start symbol: <undetermined>. *)

    | MenhirState458 : ((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ARROW, 'r) _menhir_state
      (** State 458.
        Stack shape : WHEN pattern_list expr ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState459 : (('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_state
      (** State 459.
        Stack shape : ASSERT.
        Start symbol: <undetermined>. *)

    | MenhirState460 : ((('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 460.
        Stack shape : ASSERT expr.
        Start symbol: <undetermined>. *)

    | MenhirState463 : (('s, 'r) _menhir_cell1_stmt, 'r) _menhir_state
      (** State 463.
        Stack shape : stmt.
        Start symbol: <undetermined>. *)

    | MenhirState464 : (('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_state
      (** State 464.
        Stack shape : local_decl_keyword_non_var.
        Start symbol: <undetermined>. *)

    | MenhirState466 : ((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 466.
        Stack shape : local_decl_keyword_non_var decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState467 : (((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 467.
        Stack shape : local_decl_keyword_non_var decl_item EQ.
        Start symbol: <undetermined>. *)

    | MenhirState468 : ((((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 468.
        Stack shape : local_decl_keyword_non_var decl_item EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState471 : (((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_state
      (** State 471.
        Stack shape : local_decl_keyword_non_var decl_item as_ty.
        Start symbol: <undetermined>. *)

    | MenhirState472 : ((((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 472.
        Stack shape : local_decl_keyword_non_var decl_item as_ty expr.
        Start symbol: <undetermined>. *)

    | MenhirState478 : (('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_state
      (** State 478.
        Stack shape : lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState479 : ((('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 479.
        Stack shape : lexpr expr.
        Start symbol: <undetermined>. *)

    | MenhirState481 : (('s, 'r) _menhir_cell1_call, 'r) _menhir_state
      (** State 481.
        Stack shape : call.
        Start symbol: <undetermined>. *)

    | MenhirState484 : ((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 484.
        Stack shape : call DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState487 : (((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_state
      (** State 487.
        Stack shape : call DOT LBRACKET clist2(IDENTIFIER) RBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState488 : ((((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 488.
        Stack shape : call DOT LBRACKET clist2(IDENTIFIER) RBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState490 : (('s, 'r) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 490.
        Stack shape : DOT IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState493 : ((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_state
      (** State 493.
        Stack shape : call setter_access.
        Start symbol: <undetermined>. *)

    | MenhirState494 : (((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 494.
        Stack shape : call setter_access EQ.
        Start symbol: <undetermined>. *)

    | MenhirState495 : ((((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 495.
        Stack shape : call setter_access EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState498 : (((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_slices, 'r) _menhir_state
      (** State 498.
        Stack shape : call setter_access slices.
        Start symbol: <undetermined>. *)

    | MenhirState499 : ((((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_slices, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 499.
        Stack shape : call setter_access slices expr.
        Start symbol: <undetermined>. *)

    | MenhirState503 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_state
      (** State 503.
        Stack shape : WHEN pattern_list.
        Start symbol: <undetermined>. *)

    | MenhirState507 : ((((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_cell1_list1_case_alt_, 'r) _menhir_state
      (** State 507.
        Stack shape : CASE expr OF list1(case_alt).
        Start symbol: <undetermined>. *)

    | MenhirState513 : (('s, 'r) _menhir_cell1_case_alt, 'r) _menhir_state
      (** State 513.
        Stack shape : case_alt.
        Start symbol: <undetermined>. *)

    | MenhirState518 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 518.
        Stack shape : IF expr THEN stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState519 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 519.
        Stack shape : expr THEN stmt_list ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState520 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 520.
        Stack shape : expr THEN stmt_list ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState521 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 521.
        Stack shape : expr THEN stmt_list ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState522 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 522.
        Stack shape : expr THEN stmt_list ELSIF expr THEN stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState523 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 523.
        Stack shape : expr THEN stmt_list ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState530 : ((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 530.
        Stack shape : REPEAT stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState531 : (((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 531.
        Stack shape : REPEAT stmt_list expr.
        Start symbol: <undetermined>. *)

    | MenhirState535 : ((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 535.
        Stack shape : TRY stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState536 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 536.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState538 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON, 'r) _menhir_state
      (** State 538.
        Stack shape : WHEN IDENTIFIER COLON.
        Start symbol: <undetermined>. *)

    | MenhirState540 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 540.
        Stack shape : WHEN IDENTIFIER COLON ty.
        Start symbol: <undetermined>. *)

    | MenhirState543 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 543.
        Stack shape : WHEN ty.
        Start symbol: <undetermined>. *)

    | MenhirState547 : (((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_list1_catcher_, 'r) _menhir_state
      (** State 547.
        Stack shape : TRY stmt_list list1(catcher).
        Start symbol: <undetermined>. *)

    | MenhirState552 : (('s, 'r) _menhir_cell1_catcher, 'r) _menhir_state
      (** State 552.
        Stack shape : catcher.
        Start symbol: <undetermined>. *)

    | MenhirState560 : ('s, _menhir_box_spec) _menhir_state
      (** State 560.
        Stack shape : .
        Start symbol: spec. *)

    | MenhirState561 : (('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_state
      (** State 561.
        Stack shape : VAR.
        Start symbol: spec. *)

    | MenhirState564 : ((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 564.
        Stack shape : VAR ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState566 : (((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_state
      (** State 566.
        Stack shape : VAR ignored_or_identifier option(as_ty).
        Start symbol: spec. *)

    | MenhirState567 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 567.
        Stack shape : VAR ignored_or_identifier option(as_ty) expr.
        Start symbol: spec. *)

    | MenhirState572 : (('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 572.
        Stack shape : TYPE IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState575 : (('s, _menhir_box_spec) _menhir_cell1_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 575.
        Stack shape : SUBTYPES IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState576 : (('s, _menhir_box_spec) _menhir_cell1_LBRACE, _menhir_box_spec) _menhir_state
      (** State 576.
        Stack shape : LBRACE.
        Start symbol: spec. *)

    | MenhirState579 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 579.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState582 : (('s, _menhir_box_spec) _menhir_cell1_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 582.
        Stack shape : typed_identifier.
        Start symbol: spec. *)

    | MenhirState587 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_state
      (** State 587.
        Stack shape : TYPE IDENTIFIER OF.
        Start symbol: spec. *)

    | MenhirState588 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_RECORD, _menhir_box_spec) _menhir_state
      (** State 588.
        Stack shape : TYPE IDENTIFIER OF RECORD.
        Start symbol: spec. *)

    | MenhirState591 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_EXCEPTION, _menhir_box_spec) _menhir_state
      (** State 591.
        Stack shape : TYPE IDENTIFIER OF EXCEPTION.
        Start symbol: spec. *)

    | MenhirState594 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE, _menhir_box_spec) _menhir_state
      (** State 594.
        Stack shape : TYPE IDENTIFIER OF ENUMERATION LBRACE.
        Start symbol: spec. *)

    | MenhirState596 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 596.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState600 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_COLLECTION, _menhir_box_spec) _menhir_state
      (** State 600.
        Stack shape : TYPE IDENTIFIER OF COLLECTION.
        Start symbol: spec. *)

    | MenhirState602 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl, _menhir_box_spec) _menhir_state
      (** State 602.
        Stack shape : TYPE IDENTIFIER OF ty_decl.
        Start symbol: spec. *)

    | MenhirState610 : (('s, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 610.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState616 : (('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 616.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState617 : (('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE, _menhir_box_spec) _menhir_state
      (** State 617.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: spec. *)

    | MenhirState618 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 618.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState621 : (('s, _menhir_box_spec) _menhir_cell1_opt_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 621.
        Stack shape : opt_typed_identifier.
        Start symbol: spec. *)

    | MenhirState625 : ((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 625.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState626 : ((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR, _menhir_box_spec) _menhir_state
      (** State 626.
        Stack shape : IDENTIFIER params_opt LPAR.
        Start symbol: spec. *)

    | MenhirState628 : (('s, _menhir_box_spec) _menhir_cell1_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 628.
        Stack shape : typed_identifier.
        Start symbol: spec. *)

    | MenhirState633 : (((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 633.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState634 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 634.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState639 : (((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_ARROW, _menhir_box_spec) _menhir_state
      (** State 639.
        Stack shape : IDENTIFIER params_opt func_args ARROW.
        Start symbol: spec. *)

    | MenhirState641 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 641.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState642 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT, _menhir_box_spec) _menhir_state
      (** State 642.
        Stack shape : IDENTIFIER params_opt func_args return_type RECURSELIMIT.
        Start symbol: spec. *)

    | MenhirState643 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 643.
        Stack shape : IDENTIFIER params_opt func_args return_type RECURSELIMIT expr.
        Start symbol: spec. *)

    | MenhirState645 : (((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 645.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState650 : (('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 650.
        Stack shape : IMPLEMENTATION IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState651 : ((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 651.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState654 : (((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 654.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState656 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 656.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState657 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_state
      (** State 657.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER.
        Start symbol: spec. *)

    | MenhirState661 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 661.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState665 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_state
      (** State 665.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END.
        Start symbol: spec. *)

    | MenhirState669 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_state
      (** State 669.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty GETTER.
        Start symbol: spec. *)

    | MenhirState672 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_state
      (** State 672.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty GETTER maybe_empty_stmt_list END.
        Start symbol: spec. *)

    | MenhirState677 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 677.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty GETTER maybe_empty_stmt_list END SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState686 : (('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 686.
        Stack shape : IMPDEF FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState687 : ((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 687.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState688 : (((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 688.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState689 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 689.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState693 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 693.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState695 : (((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 695.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState700 : (('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 700.
        Stack shape : IMPDEF IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState701 : ((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 701.
        Stack shape : IMPDEF IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState704 : (((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 704.
        Stack shape : IMPDEF IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState706 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 706.
        Stack shape : IMPDEF IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState711 : (('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 711.
        Stack shape : FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState712 : ((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 712.
        Stack shape : FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState713 : (((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 713.
        Stack shape : FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState714 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 714.
        Stack shape : FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState718 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 718.
        Stack shape : FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState720 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 720.
        Stack shape : FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState725 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_state
      (** State 725.
        Stack shape : CONFIG.
        Start symbol: spec. *)

    | MenhirState726 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 726.
        Stack shape : CONFIG ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState728 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 728.
        Stack shape : CONFIG ignored_or_identifier as_ty.
        Start symbol: spec. *)

    | MenhirState729 : ((((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 729.
        Stack shape : CONFIG ignored_or_identifier as_ty expr.
        Start symbol: spec. *)

    | MenhirState732 : (('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 732.
        Stack shape : ACCESSOR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState733 : ((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 733.
        Stack shape : ACCESSOR IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState736 : (((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 736.
        Stack shape : ACCESSOR IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState738 : ((((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 738.
        Stack shape : ACCESSOR IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState745 : (('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_state
      (** State 745.
        Stack shape : global_let_or_constant.
        Start symbol: spec. *)

    | MenhirState746 : ((('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 746.
        Stack shape : global_let_or_constant ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState748 : (((('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_state
      (** State 748.
        Stack shape : global_let_or_constant ignored_or_identifier option(as_ty).
        Start symbol: spec. *)

    | MenhirState749 : ((((('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 749.
        Stack shape : global_let_or_constant ignored_or_identifier option(as_ty) expr.
        Start symbol: spec. *)

    | MenhirState752 : (('s, _menhir_box_spec) _menhir_cell1_decl, _menhir_box_spec) _menhir_state
      (** State 752.
        Stack shape : decl.
        Start symbol: spec. *)

    | MenhirState754 : ('s, _menhir_box_stmts) _menhir_state
      (** State 754.
        Stack shape : .
        Start symbol: stmts. *)

  
  and ('s, 'r) _menhir_cell1_access = 
    | MenhirCell1_access of 's * ('s, 'r) _menhir_state * (Desugar.field_or_array_access list)
  
  and ('s, 'r) _menhir_cell1_as_ty = 
    | MenhirCell1_as_ty of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_bitfield = 
    | MenhirCell1_bitfield of 's * ('s, 'r) _menhir_state * (AST.bitfield)
  
  and ('s, 'r) _menhir_cell1_call = 
    | MenhirCell1_call of 's * ('s, 'r) _menhir_state * (AST.call) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_case_alt = 
    | MenhirCell1_case_alt of 's * ('s, 'r) _menhir_state * (AST.case_alt_desc AST.annotated)
  
  and ('s, 'r) _menhir_cell1_catcher = 
    | MenhirCell1_catcher of 's * ('s, 'r) _menhir_state * (AST.catcher)
  
  and ('s, 'r) _menhir_cell1_clist1_expr_ = 
    | MenhirCell1_clist1_expr_ of 's * ('s, 'r) _menhir_state * (AST.expr list)
  
  and ('s, 'r) _menhir_cell1_clist2_IDENTIFIER_ = 
    | MenhirCell1_clist2_IDENTIFIER_ of 's * ('s, 'r) _menhir_state * (string list)
  
  and ('s, 'r) _menhir_cell1_clist2_annotated_IDENTIFIER__ = 
    | MenhirCell1_clist2_annotated_IDENTIFIER__ of 's * ('s, 'r) _menhir_state * (string AST.annotated list)
  
  and ('s, 'r) _menhir_cell1_decl = 
    | MenhirCell1_decl of 's * ('s, 'r) _menhir_state * (AST.decl list)
  
  and ('s, 'r) _menhir_cell1_decl_item = 
    | MenhirCell1_decl_item of 's * ('s, 'r) _menhir_state * (AST.local_decl_item)
  
  and ('s, 'r) _menhir_cell1_direction = 
    | MenhirCell1_direction of 's * ('s, 'r) _menhir_state * (AST.for_direction)
  
  and ('s, 'r) _menhir_cell1_discard_or_basic_lexpr = 
    | MenhirCell1_discard_or_basic_lexpr of 's * ('s, 'r) _menhir_state * ((string AST.annotated * Desugar.lhs_access) option)
  
  and ('s, 'r) _menhir_cell1_discard_or_field = 
    | MenhirCell1_discard_or_field of 's * ('s, 'r) _menhir_state * (Desugar.lhs_field option)
  
  and ('s, 'r) _menhir_cell1_discard_or_identifier = 
    | MenhirCell1_discard_or_identifier of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_expr = 
    | MenhirCell1_expr of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_expr_pattern = 
    | MenhirCell1_expr_pattern of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_field_assign = 
    | MenhirCell1_field_assign of 's * ('s, 'r) _menhir_state * (string * AST.expr)
  
  and ('s, 'r) _menhir_cell1_func_args = 
    | MenhirCell1_func_args of 's * ('s, 'r) _menhir_state * (AST.typed_identifier list)
  
  and ('s, 'r) _menhir_cell1_global_let_or_constant = 
    | MenhirCell1_global_let_or_constant of 's * ('s, 'r) _menhir_state * (AST.global_decl_keyword) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ignored_or_identifier = 
    | MenhirCell1_ignored_or_identifier of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_int_constraint = 
    | MenhirCell1_int_constraint of 's * ('s, 'r) _menhir_state * (AST.int_constraint)
  
  and ('s, 'r) _menhir_cell1_lexpr = 
    | MenhirCell1_lexpr of 's * ('s, 'r) _menhir_state * (AST.lexpr) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_list1_case_alt_ = 
    | MenhirCell1_list1_case_alt_ of 's * ('s, 'r) _menhir_state * (AST.case_alt_desc AST.annotated list)
  
  and ('s, 'r) _menhir_cell1_list1_catcher_ = 
    | MenhirCell1_list1_catcher_ of 's * ('s, 'r) _menhir_state * (AST.catcher list)
  
  and ('s, 'r) _menhir_cell1_local_decl_keyword_non_var = 
    | MenhirCell1_local_decl_keyword_non_var of 's * ('s, 'r) _menhir_state * (AST.local_decl_keyword) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_loop_limit = 
    | MenhirCell1_loop_limit of 's * ('s, 'r) _menhir_state * (AST.expr option)
  
  and ('s, 'r) _menhir_cell1_maybe_empty_stmt_list = 
    | MenhirCell1_maybe_empty_stmt_list of 's * ('s, 'r) _menhir_state * (AST.stmt)
  
  and ('s, 'r) _menhir_cell1_opt_typed_identifier = 
    | MenhirCell1_opt_typed_identifier of 's * ('s, 'r) _menhir_state * (string * AST.ty option)
  
  and ('s, 'r) _menhir_cell1_option_as_ty_ = 
    | MenhirCell1_option_as_ty_ of 's * ('s, 'r) _menhir_state * (AST.ty option)
  
  and ('s, 'r) _menhir_cell1_params_opt = 
    | MenhirCell1_params_opt of 's * ('s, 'r) _menhir_state * ((string * AST.ty option) list)
  
  and ('s, 'r) _menhir_cell1_pattern = 
    | MenhirCell1_pattern of 's * ('s, 'r) _menhir_state * (AST.pattern) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_pattern_list = 
    | MenhirCell1_pattern_list of 's * ('s, 'r) _menhir_state * (AST.pattern)
  
  and ('s, 'r) _menhir_cell1_recurse_limit = 
    | MenhirCell1_recurse_limit of 's * ('s, 'r) _menhir_state * (AST.expr option)
  
  and ('s, 'r) _menhir_cell1_return_type = 
    | MenhirCell1_return_type of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_setter_access = 
    | MenhirCell1_setter_access of 's * ('s, 'r) _menhir_state * (Desugar.field_or_array_access list)
  
  and ('s, 'r) _menhir_cell1_slice = 
    | MenhirCell1_slice of 's * ('s, 'r) _menhir_state * (AST.slice)
  
  and ('s, 'r) _menhir_cell1_slices = 
    | MenhirCell1_slices of 's * ('s, 'r) _menhir_state * (AST.slice list) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_stmt = 
    | MenhirCell1_stmt of 's * ('s, 'r) _menhir_state * (AST.stmt_desc AST.annotated) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_stmt_list = 
    | MenhirCell1_stmt_list of 's * ('s, 'r) _menhir_state * (AST.stmt) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ty = 
    | MenhirCell1_ty of 's * ('s, 'r) _menhir_state * (AST.ty) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ty_decl = 
    | MenhirCell1_ty_decl of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_typed_identifier = 
    | MenhirCell1_typed_identifier of 's * ('s, 'r) _menhir_state * (AST.field)
  
  and ('s, 'r) _menhir_cell1_ACCESSOR = 
    | MenhirCell1_ACCESSOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_AND = 
    | MenhirCell1_AND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ARBITRARY = 
    | MenhirCell1_ARBITRARY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARRAY = 
    | MenhirCell1_ARRAY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARROW = 
    | MenhirCell1_ARROW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_AS = 
    | MenhirCell1_AS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ASSERT = 
    | MenhirCell1_ASSERT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BAND = 
    | MenhirCell1_BAND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BEGIN = 
    | MenhirCell1_BEGIN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BEQ = 
    | MenhirCell1_BEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BITS = 
    | MenhirCell1_BITS of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BNOT = 
    | MenhirCell1_BNOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BOR = 
    | MenhirCell1_BOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CASE = 
    | MenhirCell1_CASE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLLECTION = 
    | MenhirCell1_COLLECTION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON = 
    | MenhirCell1_COLON of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_COLON = 
    | MenhirCell0_COLON of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON_COLON = 
    | MenhirCell1_COLON_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_COMMA = 
    | MenhirCell1_COMMA of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CONFIG = 
    | MenhirCell1_CONFIG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DEBUG = 
    | MenhirCell1_DEBUG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DIV = 
    | MenhirCell1_DIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DIVRM = 
    | MenhirCell1_DIVRM of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DOT = 
    | MenhirCell1_DOT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSE = 
    | MenhirCell1_ELSE of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSIF = 
    | MenhirCell1_ELSIF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_END = 
    | MenhirCell0_END of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ENUMERATION = 
    | MenhirCell1_ENUMERATION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_EQ = 
    | MenhirCell1_EQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EQ_OP = 
    | MenhirCell1_EQ_OP of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EXCEPTION = 
    | MenhirCell1_EXCEPTION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FOR = 
    | MenhirCell1_FOR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FUNC = 
    | MenhirCell1_FUNC of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_FUNC = 
    | MenhirCell0_FUNC of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GEQ = 
    | MenhirCell1_GEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GETTER = 
    | MenhirCell1_GETTER of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_GT = 
    | MenhirCell1_GT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IDENTIFIER = 
    | MenhirCell1_IDENTIFIER of 's * ('s, 'r) _menhir_state * (
# 134 "asllib/Tokens.mly"
       (string)
# 2185 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_IDENTIFIER = 
    | MenhirCell0_IDENTIFIER of 's * (
# 134 "asllib/Tokens.mly"
       (string)
# 2192 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IF = 
    | MenhirCell1_IF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IMPDEF = 
    | MenhirCell1_IMPDEF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IMPL = 
    | MenhirCell1_IMPL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IMPLEMENTATION = 
    | MenhirCell1_IMPLEMENTATION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IN = 
    | MenhirCell1_IN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_INTEGER = 
    | MenhirCell1_INTEGER of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACE = 
    | MenhirCell1_LBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LBRACE = 
    | MenhirCell0_LBRACE of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACKET = 
    | MenhirCell1_LBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LBRACKET = 
    | MenhirCell0_LBRACKET of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LEQ = 
    | MenhirCell1_LEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LLBRACKET = 
    | MenhirCell1_LLBRACKET of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LOOPLIMIT = 
    | MenhirCell1_LOOPLIMIT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LPAR = 
    | MenhirCell1_LPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LPAR = 
    | MenhirCell0_LPAR of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LT = 
    | MenhirCell1_LT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MINUS = 
    | MenhirCell1_MINUS of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MOD = 
    | MenhirCell1_MOD of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MUL = 
    | MenhirCell1_MUL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NEQ = 
    | MenhirCell1_NEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NOT = 
    | MenhirCell1_NOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_OF = 
    | MenhirCell1_OF of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_OR = 
    | MenhirCell1_OR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PLUS = 
    | MenhirCell1_PLUS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PLUS_COLON = 
    | MenhirCell1_PLUS_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_POW = 
    | MenhirCell1_POW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PRAGMA = 
    | MenhirCell1_PRAGMA of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PRINT = 
    | MenhirCell1_PRINT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PRINTLN = 
    | MenhirCell1_PRINTLN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RBRACE = 
    | MenhirCell1_RBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_RBRACE = 
    | MenhirCell0_RBRACE of 's * Lexing.position
  
  and 's _menhir_cell0_RBRACKET = 
    | MenhirCell0_RBRACKET of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RDIV = 
    | MenhirCell1_RDIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_RECORD = 
    | MenhirCell1_RECORD of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RECURSELIMIT = 
    | MenhirCell1_RECURSELIMIT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_REPEAT = 
    | MenhirCell1_REPEAT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RETURN = 
    | MenhirCell1_RETURN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RPAR = 
    | MenhirCell1_RPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RRBRACKET = 
    | MenhirCell1_RRBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_SEMI_COLON = 
    | MenhirCell0_SEMI_COLON of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SETTER = 
    | MenhirCell1_SETTER of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SHL = 
    | MenhirCell1_SHL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SHR = 
    | MenhirCell1_SHR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SLICING = 
    | MenhirCell1_SLICING of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_STAR_COLON = 
    | MenhirCell1_STAR_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SUBTYPES = 
    | MenhirCell1_SUBTYPES of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_THEN = 
    | MenhirCell1_THEN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_THROW = 
    | MenhirCell1_THROW of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TRY = 
    | MenhirCell1_TRY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPE = 
    | MenhirCell1_TYPE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_VAR = 
    | MenhirCell1_VAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHEN = 
    | MenhirCell1_WHEN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHILE = 
    | MenhirCell1_WHILE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_XOR = 
    | MenhirCell1_XOR of 's * ('s, 'r) _menhir_state
  
  and _menhir_box_stmts = 
    | MenhirBox_stmts of (AST.stmt) [@@unboxed]
  
  and _menhir_box_spec = 
    | MenhirBox_spec of (AST.t) [@@unboxed]
  
  and _menhir_box_opn = 
    | MenhirBox_opn of (AST.t) [@@unboxed]
  
  let _menhir_action_003 =
    fun () ->
      (
# 418 "asllib/Parser.mly"
    ( [] )
# 2371 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_004 =
    fun _1 _endpos_desc_ _startpos_desc_ desc t ->
      let h =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2382 "asllib/Parser.ml"
        
      in
      (
# 419 "asllib/Parser.mly"
                                            ( FieldAccess h :: t )
# 2388 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_005 =
    fun _1 _3 idx t ->
      (
# 420 "asllib/Parser.mly"
                                              ( ArrayAccess idx :: t )
# 2396 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_006 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter ->
      let _6 =
        let (_2, _1) = (_2_inlined1, _1_inlined2) in
        ()
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 605 "asllib/Parser.mly"
    ( { getter; setter } )
# 2412 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_007 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2427 "asllib/Parser.ml"
        
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 605 "asllib/Parser.mly"
    ( { getter; setter } )
# 2437 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_008 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter ->
      let _6 =
        let _1 = _1_inlined2 in
        ()
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2456 "asllib/Parser.ml"
        
      in
      (
# 605 "asllib/Parser.mly"
    ( { getter; setter } )
# 2462 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_009 =
    fun _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2477 "asllib/Parser.ml"
        
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2490 "asllib/Parser.ml"
        
      in
      (
# 605 "asllib/Parser.mly"
    ( { getter; setter } )
# 2496 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_010 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter ->
      let _6 =
        let (_2, _1) = (_2_inlined1, _1_inlined2) in
        ()
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 608 "asllib/Parser.mly"
    ( { getter; setter } )
# 2512 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_011 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2527 "asllib/Parser.ml"
        
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 608 "asllib/Parser.mly"
    ( { getter; setter } )
# 2537 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_012 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter ->
      let _6 =
        let _1 = _1_inlined2 in
        ()
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2556 "asllib/Parser.ml"
        
      in
      (
# 608 "asllib/Parser.mly"
    ( { getter; setter } )
# 2562 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_013 =
    fun _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2577 "asllib/Parser.ml"
        
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2590 "asllib/Parser.ml"
        
      in
      (
# 608 "asllib/Parser.mly"
    ( { getter; setter } )
# 2596 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_014 =
    fun _1 _2 ->
      (_2 : (AST.ty))
  
  let _menhir_action_015 =
    fun _endpos_desc_ _startpos_desc_ access desc ->
      let base =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2611 "asllib/Parser.ml"
        
      in
      (
# 424 "asllib/Parser.mly"
    ( ( base, {access; slices=add_dummy_annotation ~version []} ) )
# 2617 "asllib/Parser.ml"
       : (string AST.annotated * Desugar.lhs_access))
  
  let _menhir_action_016 =
    fun _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ access desc desc_inlined1 ->
      let slices =
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos_desc_inlined1_, _startpos_desc_inlined1_, desc_inlined1) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2629 "asllib/Parser.ml"
        
      in
      let base =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2638 "asllib/Parser.ml"
        
      in
      (
# 426 "asllib/Parser.mly"
    ( ( base, {access; slices} ) )
# 2644 "asllib/Parser.ml"
       : (string AST.annotated * Desugar.lhs_access))
  
  let _menhir_action_017 =
    fun s x ->
      (
# 371 "asllib/Parser.mly"
                                              ( BitField_Simple (x, s)     )
# 2652 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_018 =
    fun bf s x ->
      (
# 372 "asllib/Parser.mly"
                                              ( BitField_Nested (x, s, bf) )
# 2660 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_019 =
    fun s ty x ->
      (
# 373 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 2668 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_020 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 2676 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_021 =
    fun () ->
      (
# 368 "asllib/Parser.mly"
                     ( [] )
# 2684 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_022 =
    fun _1 ->
      (_1 : (AST.bitfield list))
  
  let _menhir_action_023 =
    fun name x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 2696 "asllib/Parser.ml"
       in
      (
# 579 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 2701 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_024 =
    fun name x ->
      let args = 
# 576 "asllib/Parser.mly"
                     ( [] )
# 2709 "asllib/Parser.ml"
       in
      let params = 
# 205 "<standard.mly>"
    ( x )
# 2714 "asllib/Parser.ml"
       in
      (
# 581 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 2719 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_025 =
    fun name x x_inlined1 ->
      let args =
        let x = x_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 2729 "asllib/Parser.ml"
        
      in
      let params = 
# 205 "<standard.mly>"
    ( x )
# 2735 "asllib/Parser.ml"
       in
      (
# 581 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 2740 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_026 =
    fun _1 _4 _endpos_stmt_ _startpos__1_ pattern stmt ->
      let desc =
        let where = 
# 123 "<standard.mly>"
    ( None )
# 2749 "asllib/Parser.ml"
         in
        
# 488 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 2754 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_stmt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2763 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated))
  
  let _menhir_action_027 =
    fun _1 _1_inlined1 _2 _4 _endpos_stmt_ _startpos__1_ pattern stmt ->
      let desc =
        let where =
          let _1 = _1_inlined1 in
          let x = _2 in
          
# 126 "<standard.mly>"
    ( Some x )
# 2775 "asllib/Parser.ml"
          
        in
        
# 488 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 2781 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_stmt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2790 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated))
  
  let _menhir_action_028 =
    fun _1 _4 stmt_list ty ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 2798 "asllib/Parser.ml"
       in
      let _2_1 = _2 in
      ((_2_1, ty, stmt_list) : (AST.catcher))
  
  let _menhir_action_029 =
    fun _1 _4 stmt_list ty x ->
      let _2 =
        let x = 
# 196 "<standard.mly>"
    ( x )
# 2809 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 2814 "asllib/Parser.ml"
        
      in
      let _2_1 = _2 in
      ((_2_1, ty, stmt_list) : (AST.catcher))
  
  let _menhir_action_030 =
    fun () ->
      (
# 162 "asllib/Parser.mly"
                 ( [] )
# 2825 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_031 =
    fun _1 ->
      (_1 : (AST.expr list))
  
  let _menhir_action_032 =
    fun () ->
      (
# 162 "asllib/Parser.mly"
                 ( [] )
# 2837 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_033 =
    fun _1 ->
      (_1 : (AST.ty list))
  
  let _menhir_action_034 =
    fun () ->
      (
# 162 "asllib/Parser.mly"
                 ( [] )
# 2849 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_035 =
    fun _1 ->
      (_1 : (AST.typed_identifier list))
  
  let _menhir_action_036 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2861 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_037 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2869 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_038 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let x =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2880 "asllib/Parser.ml"
        
      in
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2886 "asllib/Parser.ml"
       : (string AST.annotated list))
  
  let _menhir_action_039 =
    fun _2 _endpos_desc_ _startpos_desc_ desc t ->
      let h =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2897 "asllib/Parser.ml"
        
      in
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2903 "asllib/Parser.ml"
       : (string AST.annotated list))
  
  let _menhir_action_040 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2911 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option list))
  
  let _menhir_action_041 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2919 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option list))
  
  let _menhir_action_042 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2927 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_043 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2935 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_044 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2943 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_045 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2951 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_046 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2959 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_047 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2967 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_048 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2975 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_049 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2983 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_050 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 2991 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_051 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 2999 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_052 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3007 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_053 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3015 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_054 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3023 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_055 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3031 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_056 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3039 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_057 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3047 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_058 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3055 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_059 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3063 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_060 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3071 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_061 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3079 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_062 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3087 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_063 =
    fun _2 _endpos_desc_ _startpos_desc_ desc li ->
      let x =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3098 "asllib/Parser.ml"
        
      in
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3104 "asllib/Parser.ml"
       : (string AST.annotated list))
  
  let _menhir_action_064 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3112 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option list))
  
  let _menhir_action_065 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3120 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_066 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3128 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_067 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3136 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_068 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3144 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_069 =
    fun x ->
      let cs = 
# 205 "<standard.mly>"
    ( x )
# 3152 "asllib/Parser.ml"
       in
      (
# 294 "asllib/Parser.mly"
                                       ( WellConstrained (cs, Precision_Full) )
# 3157 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_070 =
    fun x ->
      let _1 = 
# 205 "<standard.mly>"
    ( x )
# 3165 "asllib/Parser.ml"
       in
      (
# 295 "asllib/Parser.mly"
                   ( PendingConstrained )
# 3170 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_071 =
    fun _1 ->
      (_1 : (AST.constraint_kind))
  
  let _menhir_action_072 =
    fun () ->
      (
# 292 "asllib/Parser.mly"
                                             ( UnConstrained )
# 3182 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_073 =
    fun _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _2 = _2_inlined1 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3198 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3204 "asllib/Parser.ml"
           in
          
# 614 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3221 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3230 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3236 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_074 =
    fun _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3254 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3260 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3266 "asllib/Parser.ml"
           in
          
# 614 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3283 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3292 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3298 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_075 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3314 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 599 "asllib/Parser.mly"
              ( Impdef )
# 3321 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3326 "asllib/Parser.ml"
            
          in
          
# 614 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3344 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3353 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3359 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_076 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3378 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3384 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 599 "asllib/Parser.mly"
              ( Impdef )
# 3391 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3396 "asllib/Parser.ml"
            
          in
          
# 614 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3414 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3423 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3429 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_077 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3445 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 600 "asllib/Parser.mly"
                      ( Implementation )
# 3452 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3457 "asllib/Parser.ml"
            
          in
          
# 614 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3475 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3484 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3490 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_078 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3509 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3515 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 600 "asllib/Parser.mly"
                      ( Implementation )
# 3522 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3527 "asllib/Parser.ml"
            
          in
          
# 614 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3545 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3554 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3560 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_079 =
    fun _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _2 = _2_inlined1 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3576 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3582 "asllib/Parser.ml"
           in
          
# 630 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3599 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3608 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3614 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_080 =
    fun _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3632 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3638 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3644 "asllib/Parser.ml"
           in
          
# 630 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3661 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3670 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3676 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_081 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3692 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 599 "asllib/Parser.mly"
              ( Impdef )
# 3699 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3704 "asllib/Parser.ml"
            
          in
          
# 630 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3722 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3731 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3737 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_082 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3756 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3762 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 599 "asllib/Parser.mly"
              ( Impdef )
# 3769 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3774 "asllib/Parser.ml"
            
          in
          
# 630 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3792 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3801 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3807 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_083 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3823 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 600 "asllib/Parser.mly"
                      ( Implementation )
# 3830 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3835 "asllib/Parser.ml"
            
          in
          
# 630 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3853 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3862 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3868 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_084 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3887 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3893 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 600 "asllib/Parser.mly"
                      ( Implementation )
# 3900 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3905 "asllib/Parser.ml"
            
          in
          
# 630 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3923 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3932 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3938 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_085 =
    fun _1 _3 _endpos__2_ _startpos__1_ subtype_opt t x ->
      let d =
        let desc =
          let x = 
# 646 "asllib/Parser.mly"
                                                            D_TypeDecl            
# 3948 "asllib/Parser.ml"
           (x, t, subtype_opt) in
          
# 196 "<standard.mly>"
    ( x )
# 3953 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3962 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 3968 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_086 =
    fun _1 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc x ->
      let d =
        let desc =
          let x =
            let s =
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3982 "asllib/Parser.ml"
              
            in
            
# 649 "asllib/Parser.mly"
                                                            make_ty_decl_subtype  
# 3988 "asllib/Parser.ml"
             (x, s)
          in
          
# 196 "<standard.mly>"
    ( x )
# 3994 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4003 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 4009 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_087 =
    fun _4 _endpos__2_ _startpos_keyword_ keyword name ty x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 144 "asllib/Parser.mly"
                        Some 
# 4020 "asllib/Parser.ml"
             x in
            
# 654 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 4025 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 4031 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_keyword_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4040 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 4046 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_088 =
    fun _1 _4 _endpos__2_ _startpos__1_ name ty x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 144 "asllib/Parser.mly"
                        Some 
# 4057 "asllib/Parser.ml"
             x in
            
# 657 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Config; name; ty=Some ty; initial_value } )
# 4062 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 4068 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4077 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 4083 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_089 =
    fun _1 _4 _endpos__2_ _startpos__1_ name ty x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 144 "asllib/Parser.mly"
                        Some 
# 4094 "asllib/Parser.ml"
             x in
            
# 660 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value } )
# 4099 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 4105 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4114 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 4120 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_090 =
    fun _1 _endpos__2_ _startpos__1_ name x ->
      let d =
        let desc =
          let x =
            let ty = 
# 144 "asllib/Parser.mly"
                        Some 
# 4131 "asllib/Parser.ml"
             x in
            
# 664 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value=None})
# 4136 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 4142 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4151 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 4157 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_091 =
    fun _1 _endpos__2_ _startpos__1_ e x ->
      let d =
        let desc =
          let x = 
# 667 "asllib/Parser.mly"
                                                D_Pragma  
# 4167 "asllib/Parser.ml"
           (x, e) in
          
# 196 "<standard.mly>"
    ( x )
# 4172 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4181 "asllib/Parser.ml"
        
      in
      (
# 670 "asllib/Parser.mly"
     ( [d] )
# 4187 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_092 =
    fun _1 _1_inlined1 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let _2 = _2_inlined1 in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 676 "asllib/Parser.mly"
  ( accessors )
# 4201 "asllib/Parser.ml"
        
      in
      let override = 
# 123 "<standard.mly>"
    ( None )
# 4207 "asllib/Parser.ml"
       in
      (
# 673 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4212 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_093 =
    fun _1 _1_inlined1 _2 _6 _endpos__1_inlined1_ _startpos__1_inlined1_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4228 "asllib/Parser.ml"
          
        in
        
# 676 "asllib/Parser.mly"
  ( accessors )
# 4234 "asllib/Parser.ml"
        
      in
      let override = 
# 123 "<standard.mly>"
    ( None )
# 4240 "asllib/Parser.ml"
       in
      (
# 673 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4245 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_094 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_2, _1_inlined1, _1) = (_2_inlined1, _1_inlined2, _1_inlined1) in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 676 "asllib/Parser.mly"
  ( accessors )
# 4259 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 599 "asllib/Parser.mly"
              ( Impdef )
# 4266 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4271 "asllib/Parser.ml"
        
      in
      (
# 673 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4277 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_095 =
    fun _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2, _1_inlined1) in
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4294 "asllib/Parser.ml"
          
        in
        
# 676 "asllib/Parser.mly"
  ( accessors )
# 4300 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 599 "asllib/Parser.mly"
              ( Impdef )
# 4307 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4312 "asllib/Parser.ml"
        
      in
      (
# 673 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4318 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_096 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_2, _1_inlined1, _1) = (_2_inlined1, _1_inlined2, _1_inlined1) in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 676 "asllib/Parser.mly"
  ( accessors )
# 4332 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 600 "asllib/Parser.mly"
                      ( Implementation )
# 4339 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4344 "asllib/Parser.ml"
        
      in
      (
# 673 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4350 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_097 =
    fun _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2, _1_inlined1) in
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4367 "asllib/Parser.ml"
          
        in
        
# 676 "asllib/Parser.mly"
  ( accessors )
# 4373 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 600 "asllib/Parser.mly"
                      ( Implementation )
# 4380 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4385 "asllib/Parser.ml"
        
      in
      (
# 673 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4391 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_098 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _startpos = _startpos__1_ in
      (
# 456 "asllib/Parser.mly"
                                       (
      if Config.allow_storage_discards then LDI_Var (local_ignored ())
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
    )
# 4404 "asllib/Parser.ml"
       : (AST.local_decl_item))
  
  let _menhir_action_099 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 460 "asllib/Parser.mly"
                                         LDI_Var  
# 4413 "asllib/Parser.ml"
       _1_1 : (AST.local_decl_item))
  
  let _menhir_action_100 =
    fun _endpos__3_ _startpos__1_ x ->
      let vs = 
# 205 "<standard.mly>"
    ( x )
# 4421 "asllib/Parser.ml"
       in
      let (_endpos_vs_, _startpos_vs_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_vs_ in
      let _startpos = _startpos_vs_ in
      (
# 461 "asllib/Parser.mly"
                                       (
      if List.for_all is_local_ignored vs && not Config.allow_storage_discards then
        Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
      else LDI_Tuple vs
    )
# 4433 "asllib/Parser.ml"
       : (AST.local_decl_item))
  
  let _menhir_action_101 =
    fun _1 ->
      (
# 483 "asllib/Parser.mly"
                       ( AST.Up )
# 4441 "asllib/Parser.ml"
       : (AST.for_direction))
  
  let _menhir_action_102 =
    fun _1 ->
      (
# 483 "asllib/Parser.mly"
                                            ( AST.Down )
# 4449 "asllib/Parser.ml"
       : (AST.for_direction))
  
  let _menhir_action_103 =
    fun _1 ->
      (
# 429 "asllib/Parser.mly"
                          ( None )
# 4457 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option))
  
  let _menhir_action_104 =
    fun basic_lexpr ->
      (
# 430 "asllib/Parser.mly"
                            Some  
# 4465 "asllib/Parser.ml"
       basic_lexpr : ((string AST.annotated * Desugar.lhs_access) option))
  
  let _menhir_action_105 =
    fun _1 ->
      (
# 433 "asllib/Parser.mly"
                             ( None )
# 4473 "asllib/Parser.ml"
       : (Desugar.lhs_field option))
  
  let _menhir_action_106 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let _1 =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4484 "asllib/Parser.ml"
        
      in
      let _1_1 = _1 in
      (
# 434 "asllib/Parser.mly"
                               Some  
# 4491 "asllib/Parser.ml"
       _1_1 : (Desugar.lhs_field option))
  
  let _menhir_action_107 =
    fun _1 ->
      (
# 452 "asllib/Parser.mly"
                   ( local_ignored () )
# 4499 "asllib/Parser.ml"
       : (string))
  
  let _menhir_action_108 =
    fun _1 ->
      (_1 : (string))
  
  let _menhir_action_109 =
    fun _1 _2 ->
      (_2 : (AST.expr))
  
  let _menhir_action_110 =
    fun _1 _3 _endpos_e2_ _startpos__1_ c e1 e2 ->
      let desc =
        let _endpos = _endpos_e2_ in
        let _startpos = _startpos__1_ in
        
# 248 "asllib/Parser.mly"
                                                                          (
      if Config.allow_expression_elsif then E_Cond (c, e1, e2)
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Expression-level 'elsif'."
    )
# 4521 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4530 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_111 =
    fun _2 _3 name ->
      let args = 
# 576 "asllib/Parser.mly"
                     ( [] )
# 4538 "asllib/Parser.ml"
       in
      (
# 584 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 4543 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_112 =
    fun _2 _3 name x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 4551 "asllib/Parser.ml"
       in
      (
# 584 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 4556 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_113 =
    fun _2 _3 _5 name params ->
      let args = 
# 576 "asllib/Parser.mly"
                     ( [] )
# 4564 "asllib/Parser.ml"
       in
      (
# 586 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 4569 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_114 =
    fun _2 _3 _5 name params x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 4577 "asllib/Parser.ml"
       in
      (
# 586 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 4582 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_115 =
    fun _endpos_value_ _startpos_value_ value ->
      let desc = 
# 257 "asllib/Parser.mly"
                                                                    E_Literal             
# 4590 "asllib/Parser.ml"
       value in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_value_, _startpos_value_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4598 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_116 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 258 "asllib/Parser.mly"
                                                                    E_Var                 
# 4608 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4617 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_117 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 213 "asllib/Parser.mly"
                  ( `AND    )
# 4626 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4631 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4640 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_118 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
                  ( `BAND   )
# 4649 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4654 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4663 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_119 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
                  ( `BOR    )
# 4672 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4677 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4686 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_120 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 216 "asllib/Parser.mly"
                  ( `BEQ    )
# 4695 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4700 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4709 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_121 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 217 "asllib/Parser.mly"
                  ( `DIV    )
# 4718 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4723 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4732 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_122 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( `DIVRM  )
# 4741 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4746 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4755 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_123 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( `XOR    )
# 4764 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4769 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4778 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_124 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( `EQ_OP  )
# 4787 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4792 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4801 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_125 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( `NEQ    )
# 4810 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4815 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4824 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_126 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( `GT     )
# 4833 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4838 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4847 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_127 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( `GEQ    )
# 4856 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4861 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4870 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_128 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( `IMPL   )
# 4879 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4884 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4893 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_129 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( `LT     )
# 4902 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4907 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4916 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_130 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( `LEQ    )
# 4925 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4930 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4939 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_131 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( `PLUS   )
# 4948 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4953 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4962 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_132 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( `MINUS  )
# 4971 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4976 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4985 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_133 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( `MOD    )
# 4994 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 4999 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5008 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_134 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( `MUL    )
# 5017 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 5022 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5031 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_135 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( `OR     )
# 5040 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 5045 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5054 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_136 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( `RDIV   )
# 5063 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 5068 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5077 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_137 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( `SHL    )
# 5086 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 5091 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5100 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_138 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( `SHR    )
# 5109 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 5114 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5123 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_139 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( `POW    )
# 5132 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 5137 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5146 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_140 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( `CONCAT )
# 5155 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 5160 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5169 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_141 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 208 "asllib/Parser.mly"
            ( BNOT )
# 5178 "asllib/Parser.ml"
         in
        
# 260 "asllib/Parser.mly"
                                                                    E_Unop                
# 5183 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5192 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_142 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 209 "asllib/Parser.mly"
            ( NEG )
# 5201 "asllib/Parser.ml"
         in
        
# 260 "asllib/Parser.mly"
                                                                    E_Unop                
# 5206 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5215 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_143 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 210 "asllib/Parser.mly"
            ( NOT )
# 5224 "asllib/Parser.ml"
         in
        
# 260 "asllib/Parser.mly"
                                                                    E_Unop                
# 5229 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5238 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_144 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 261 "asllib/Parser.mly"
                                                                    E_Cond                
# 5246 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5254 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_145 =
    fun _endpos_call_ _startpos_call_ call ->
      let desc = 
# 262 "asllib/Parser.mly"
                                                                    e_call                
# 5262 "asllib/Parser.ml"
       call in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_call_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5270 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_146 =
    fun _endpos_slices_ _startpos_e_ e slices ->
      let desc = 
# 263 "asllib/Parser.mly"
                                                                E_Slice               
# 5278 "asllib/Parser.ml"
       (e, slices) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_slices_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5286 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_147 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 264 "asllib/Parser.mly"
                                                                E_GetArray            
# 5294 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5302 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_148 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 265 "asllib/Parser.mly"
                                                                E_GetField            
# 5310 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5318 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_149 =
    fun _2 _endpos__3_ _startpos_e_ e x ->
      let desc =
        let fs = 
# 205 "<standard.mly>"
    ( x )
# 5327 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                E_GetFields           
# 5332 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5341 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_150 =
    fun _2 _endpos_ty_ _startpos_expr_ expr ty ->
      let desc = 
# 268 "asllib/Parser.mly"
                                                                E_ATC                 
# 5349 "asllib/Parser.ml"
       (expr, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5357 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_151 =
    fun _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_ constraint_kind expr ->
      let desc =
        let implicit_t_int =
          let desc = 
# 407 "asllib/Parser.mly"
                                                       T_Int 
# 5367 "asllib/Parser.ml"
           constraint_kind in
          let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_constraint_kind_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5375 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                E_ATC                 
# 5381 "asllib/Parser.ml"
         (expr, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5390 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_152 =
    fun _2 _endpos_pattern_set_ _startpos_expr_ expr pattern_set ->
      let desc = 
# 271 "asllib/Parser.mly"
                                                                E_Pattern             
# 5398 "asllib/Parser.ml"
       (expr, pattern_set) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_pattern_set_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5406 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_153 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_ expr ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 332 "asllib/Parser.mly"
                                            Pattern_Mask  
# 5418 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5427 "asllib/Parser.ml"
          
        in
        
# 272 "asllib/Parser.mly"
                                                                E_Pattern             
# 5433 "asllib/Parser.ml"
         (expr, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5442 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_154 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 332 "asllib/Parser.mly"
                                            Pattern_Mask  
# 5454 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5463 "asllib/Parser.ml"
          
        in
        
# 273 "asllib/Parser.mly"
                                                              ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 5469 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5478 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_155 =
    fun _1 _2 _endpos_ty_ _startpos__1_ ty ->
      let desc = 
# 274 "asllib/Parser.mly"
                                                                E_Arbitrary         
# 5486 "asllib/Parser.ml"
       ty in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5494 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_156 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 5503 "asllib/Parser.ml"
         in
        
# 275 "asllib/Parser.mly"
                                                              ( E_Tuple [ e ]        )
# 5508 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5517 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_157 =
    fun _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5529 "asllib/Parser.ml"
          
        in
        
# 277 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), []) )
# 5535 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__4_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5544 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_158 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let fields = 
# 205 "<standard.mly>"
    ( x )
# 5553 "asllib/Parser.ml"
         in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5561 "asllib/Parser.ml"
          
        in
        
# 279 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 5567 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5576 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_159 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let _1 = 
# 205 "<standard.mly>"
    ( x )
# 5585 "asllib/Parser.ml"
         in
        let _1_1 = _1 in
        
# 281 "asllib/Parser.mly"
                                                                    E_Tuple               
# 5591 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5600 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_160 =
    fun _endpos_value_ _startpos_value_ value ->
      let desc = 
# 306 "asllib/Parser.mly"
                                                                    E_Literal             
# 5608 "asllib/Parser.ml"
       value in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_value_, _startpos_value_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5616 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_161 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 307 "asllib/Parser.mly"
                                                                    E_Var                 
# 5626 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5635 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_162 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 213 "asllib/Parser.mly"
                  ( `AND    )
# 5644 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5649 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5658 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_163 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
                  ( `BAND   )
# 5667 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5672 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5681 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_164 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
                  ( `BOR    )
# 5690 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5695 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5704 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_165 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 216 "asllib/Parser.mly"
                  ( `BEQ    )
# 5713 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5718 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5727 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_166 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 217 "asllib/Parser.mly"
                  ( `DIV    )
# 5736 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5741 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5750 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_167 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( `DIVRM  )
# 5759 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5764 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5773 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_168 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( `XOR    )
# 5782 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5787 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5796 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_169 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( `EQ_OP  )
# 5805 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5810 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5819 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_170 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( `NEQ    )
# 5828 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5833 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5842 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_171 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( `GT     )
# 5851 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5856 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5865 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_172 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( `GEQ    )
# 5874 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5879 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5888 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_173 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( `IMPL   )
# 5897 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5902 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5911 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_174 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( `LT     )
# 5920 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5925 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5934 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_175 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( `LEQ    )
# 5943 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5948 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5957 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_176 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( `PLUS   )
# 5966 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5971 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5980 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_177 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( `MINUS  )
# 5989 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 5994 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6003 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_178 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( `MOD    )
# 6012 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6017 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6026 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_179 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( `MUL    )
# 6035 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6040 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6049 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_180 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( `OR     )
# 6058 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6063 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6072 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_181 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( `RDIV   )
# 6081 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6086 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6095 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_182 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( `SHL    )
# 6104 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6109 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6118 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_183 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( `SHR    )
# 6127 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6132 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6141 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_184 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( `POW    )
# 6150 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6155 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6164 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_185 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( `CONCAT )
# 6173 "asllib/Parser.ml"
         in
        
# 308 "asllib/Parser.mly"
                                                                        e_binop               
# 6178 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6187 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_186 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 208 "asllib/Parser.mly"
            ( BNOT )
# 6196 "asllib/Parser.ml"
         in
        
# 309 "asllib/Parser.mly"
                                                                    E_Unop                
# 6201 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6210 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_187 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 209 "asllib/Parser.mly"
            ( NEG )
# 6219 "asllib/Parser.ml"
         in
        
# 309 "asllib/Parser.mly"
                                                                    E_Unop                
# 6224 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6233 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_188 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 210 "asllib/Parser.mly"
            ( NOT )
# 6242 "asllib/Parser.ml"
         in
        
# 309 "asllib/Parser.mly"
                                                                    E_Unop                
# 6247 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6256 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_189 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 310 "asllib/Parser.mly"
                                                                    E_Cond                
# 6264 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6272 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_190 =
    fun _endpos_call_ _startpos_call_ call ->
      let desc = 
# 311 "asllib/Parser.mly"
                                                                    e_call                
# 6280 "asllib/Parser.ml"
       call in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_call_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6288 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_191 =
    fun _endpos_slices_ _startpos_e_ e slices ->
      let desc = 
# 312 "asllib/Parser.mly"
                                                                        E_Slice               
# 6296 "asllib/Parser.ml"
       (e, slices) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_slices_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6304 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_192 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 313 "asllib/Parser.mly"
                                                                        E_GetArray            
# 6312 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6320 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_193 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 314 "asllib/Parser.mly"
                                                                        E_GetField            
# 6328 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6336 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_194 =
    fun _2 _endpos__3_ _startpos_e_ e x ->
      let desc =
        let fs = 
# 205 "<standard.mly>"
    ( x )
# 6345 "asllib/Parser.ml"
         in
        
# 315 "asllib/Parser.mly"
                                                                        E_GetFields           
# 6350 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6359 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_195 =
    fun _2 _endpos_ty_ _startpos_expr_pattern_ expr_pattern ty ->
      let desc = 
# 317 "asllib/Parser.mly"
                                                                        E_ATC                 
# 6367 "asllib/Parser.ml"
       (expr_pattern, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6375 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_196 =
    fun _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_pattern_ constraint_kind expr_pattern ->
      let desc =
        let implicit_t_int =
          let desc = 
# 407 "asllib/Parser.mly"
                                                       T_Int 
# 6385 "asllib/Parser.ml"
           constraint_kind in
          let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_constraint_kind_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6393 "asllib/Parser.ml"
          
        in
        
# 318 "asllib/Parser.mly"
                                                                        E_ATC                 
# 6399 "asllib/Parser.ml"
         (expr_pattern, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6408 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_197 =
    fun _2 _endpos_pattern_set_ _startpos_expr_pattern_ expr_pattern pattern_set ->
      let desc = 
# 320 "asllib/Parser.mly"
                                                                        E_Pattern             
# 6416 "asllib/Parser.ml"
       (expr_pattern, pattern_set) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_pattern_set_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6424 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_198 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_pattern_ expr_pattern ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 332 "asllib/Parser.mly"
                                            Pattern_Mask  
# 6436 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6445 "asllib/Parser.ml"
          
        in
        
# 321 "asllib/Parser.mly"
                                                                        E_Pattern             
# 6451 "asllib/Parser.ml"
         (expr_pattern, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6460 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_199 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 332 "asllib/Parser.mly"
                                            Pattern_Mask  
# 6472 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6481 "asllib/Parser.ml"
          
        in
        
# 322 "asllib/Parser.mly"
                                                                      ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 6487 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6496 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_200 =
    fun _1 _2 _endpos_ty_ _startpos__1_ ty ->
      let desc = 
# 324 "asllib/Parser.mly"
                                                                        E_Arbitrary         
# 6504 "asllib/Parser.ml"
       ty in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6512 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_201 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 6521 "asllib/Parser.ml"
         in
        
# 325 "asllib/Parser.mly"
                                                                      ( E_Tuple [ e ]        )
# 6526 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6535 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_202 =
    fun _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6547 "asllib/Parser.ml"
          
        in
        
# 327 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), []) )
# 6553 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__4_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6562 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_203 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let fields = 
# 205 "<standard.mly>"
    ( x )
# 6571 "asllib/Parser.ml"
         in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6579 "asllib/Parser.ml"
          
        in
        
# 329 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 6585 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6594 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_204 =
    fun x y ->
      (
# 180 "<standard.mly>"
    ( (x, y) )
# 6602 "asllib/Parser.ml"
       : (string * AST.expr))
  
  let _menhir_action_205 =
    fun x ->
      let _1 = 
# 205 "<standard.mly>"
    ( x )
# 6610 "asllib/Parser.ml"
       in
      (
# 354 "asllib/Parser.mly"
                   ( [] )
# 6615 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_206 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 6623 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_207 =
    fun () ->
      (
# 356 "asllib/Parser.mly"
                  ( [] )
# 6631 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_208 =
    fun _1 ->
      (_1 : (AST.field list))
  
  let _menhir_action_209 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 6643 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_210 =
    fun _1 ->
      (
# 478 "asllib/Parser.mly"
                ( GDK_Let      )
# 6651 "asllib/Parser.ml"
       : (AST.global_decl_keyword))
  
  let _menhir_action_211 =
    fun _1 ->
      (
# 479 "asllib/Parser.mly"
                ( GDK_Constant )
# 6659 "asllib/Parser.ml"
       : (AST.global_decl_keyword))
  
  let _menhir_action_212 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _startpos = _startpos__1_ in
      (
# 592 "asllib/Parser.mly"
                            (
      if Config.allow_storage_discards then global_ignored ()
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
    )
# 6672 "asllib/Parser.ml"
       : (string))
  
  let _menhir_action_213 =
    fun _1 ->
      (_1 : (string))
  
  let _menhir_action_214 =
    fun expr ->
      (
# 298 "asllib/Parser.mly"
                                  Constraint_Exact  
# 6684 "asllib/Parser.ml"
       expr : (AST.int_constraint))
  
  let _menhir_action_215 =
    fun _2 e1 e2 ->
      (
# 299 "asllib/Parser.mly"
                                  Constraint_Range  
# 6692 "asllib/Parser.ml"
       (e1, e2) : (AST.int_constraint))
  
  let _menhir_action_216 =
    fun basic_lexpr ->
      (
# 437 "asllib/Parser.mly"
                     desugar_lhs_access  
# 6700 "asllib/Parser.ml"
       basic_lexpr : (AST.lexpr))
  
  let _menhir_action_217 =
    fun _endpos__3_ _startpos__1_ x ->
      let _1 =
        let desc = 
# 205 "<standard.mly>"
    ( x )
# 6709 "asllib/Parser.ml"
         in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6717 "asllib/Parser.ml"
        
      in
      let _1_1 = _1 in
      (
# 438 "asllib/Parser.mly"
                                                   desugar_lhs_tuple  
# 6724 "asllib/Parser.ml"
       _1_1 : (AST.lexpr))
  
  let _menhir_action_218 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 440 "asllib/Parser.mly"
             ( LE_Discard )
# 6732 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6740 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_219 =
    fun _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let flds = 
# 205 "<standard.mly>"
    ( x )
# 6749 "asllib/Parser.ml"
         in
        let x =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6757 "asllib/Parser.ml"
          
        in
        
# 442 "asllib/Parser.mly"
      ( LE_SetFields (le_var x, flds, []) )
# 6763 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6772 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_220 =
    fun _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let flds = 
# 205 "<standard.mly>"
    ( x )
# 6781 "asllib/Parser.ml"
         in
        let x =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6789 "asllib/Parser.ml"
          
        in
        
# 444 "asllib/Parser.mly"
      ( desugar_lhs_fields_tuple x flds )
# 6795 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6804 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_221 =
    fun () ->
      (
# 216 "<standard.mly>"
    ( [] )
# 6812 "asllib/Parser.ml"
       : (AST.decl list list))
  
  let _menhir_action_222 =
    fun x xs ->
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 6820 "asllib/Parser.ml"
       : (AST.decl list list))
  
  let _menhir_action_223 =
    fun x ->
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 6828 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated list))
  
  let _menhir_action_224 =
    fun l x ->
      (
# 184 "asllib/Parser.mly"
                     ( x :: l )
# 6836 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated list))
  
  let _menhir_action_225 =
    fun x ->
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 6844 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_226 =
    fun l x ->
      (
# 184 "asllib/Parser.mly"
                     ( x :: l )
# 6852 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_227 =
    fun x ->
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 6860 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_228 =
    fun l x ->
      (
# 184 "asllib/Parser.mly"
                     ( x :: l )
# 6868 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_229 =
    fun _1 ->
      (
# 471 "asllib/Parser.mly"
                ( LDK_Let       )
# 6876 "asllib/Parser.ml"
       : (AST.local_decl_keyword))
  
  let _menhir_action_230 =
    fun _1 ->
      (
# 472 "asllib/Parser.mly"
                ( LDK_Constant  )
# 6884 "asllib/Parser.ml"
       : (AST.local_decl_keyword))
  
  let _menhir_action_231 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 6892 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_232 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 6901 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_233 =
    fun _1 ->
      (_1 : (AST.stmt))
  
  let _menhir_action_234 =
    fun _endpos__0_ ->
      let desc = 
# 588 "asllib/Parser.mly"
                                                   ( S_Pass )
# 6913 "asllib/Parser.ml"
       in
      let _endpos_desc_ = _endpos__0_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _endpos in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6921 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_235 =
    fun _2 body ->
      (
# 683 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 6945 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_236 =
    fun x ->
      let y = 
# 123 "<standard.mly>"
    ( None )
# 6953 "asllib/Parser.ml"
       in
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 6958 "asllib/Parser.ml"
       : (string * AST.ty option))
  
  let _menhir_action_237 =
    fun x x_inlined1 ->
      let y =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 6968 "asllib/Parser.ml"
        
      in
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 6974 "asllib/Parser.ml"
       : (string * AST.ty option))
  
  let _menhir_action_238 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6982 "asllib/Parser.ml"
       : (AST.ty option))
  
  let _menhir_action_239 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 6990 "asllib/Parser.ml"
       : (AST.ty option))
  
  let _menhir_action_240 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6998 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_241 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 7006 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_242 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 7014 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_243 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 7023 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_244 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 7031 "asllib/Parser.ml"
       : (AST.stmt option))
  
  let _menhir_action_245 =
    fun _1 _2 _3 ->
      let x = _3 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 7040 "asllib/Parser.ml"
       : (AST.stmt option))
  
  let _menhir_action_246 =
    fun () ->
      (
# 574 "asllib/Parser.mly"
                  ( [] )
# 7048 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_247 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 7056 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_248 =
    fun _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern ->
      let desc = 
# 337 "asllib/Parser.mly"
                        Pattern_Single  
# 7064 "asllib/Parser.ml"
       expr_pattern in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_pattern_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7072 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_249 =
    fun _2 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc = 
# 338 "asllib/Parser.mly"
                                           Pattern_Range  
# 7080 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7088 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_250 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 339 "asllib/Parser.mly"
             ( Pattern_All )
# 7096 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7104 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_251 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 340 "asllib/Parser.mly"
                     Pattern_Leq  
# 7112 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7120 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_252 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 341 "asllib/Parser.mly"
                     Pattern_Geq  
# 7128 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7136 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_253 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let _1 = 
# 205 "<standard.mly>"
    ( x )
# 7145 "asllib/Parser.ml"
         in
        let _1_1 = _1 in
        
# 342 "asllib/Parser.mly"
                           Pattern_Tuple  
# 7151 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7160 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_254 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 332 "asllib/Parser.mly"
                                            Pattern_Mask  
# 7170 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7179 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_255 =
    fun _1 ->
      (_1 : (AST.pattern))
  
  let _menhir_action_256 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 333 "asllib/Parser.mly"
                                                   Pattern_Any  
# 7193 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7202 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_257 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 7210 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_258 =
    fun _1 _endpos__3_ _startpos__1_ x ->
      let desc =
        let _2 = 
# 205 "<standard.mly>"
    ( x )
# 7219 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        
# 350 "asllib/Parser.mly"
                                      Pattern_Not  
# 7225 "asllib/Parser.ml"
         _2_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7234 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_259 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 7242 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_260 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 7251 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_261 =
    fun _1 _2 ->
      (_2 : (AST.ty))
  
  let _menhir_action_262 =
    fun _1 _3 _endpos_s2_ _startpos__1_ e s1 s2 ->
      let desc = 
# 556 "asllib/Parser.mly"
                                                     S_Cond 
# 7263 "asllib/Parser.ml"
       (e, s1, s2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_s2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7274 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_263 =
    fun _endpos__0_ ->
      let desc = 
# 481 "asllib/Parser.mly"
            ( S_Pass )
# 7282 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__0_, _endpos__0_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7293 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_264 =
    fun _1 _2 ->
      (_2 : (AST.stmt))
  
  let _menhir_action_265 =
    fun () ->
      (
# 505 "asllib/Parser.mly"
    ( [] )
# 7305 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_266 =
    fun _1 _endpos_desc_ _startpos_desc_ desc t ->
      let h =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7316 "asllib/Parser.ml"
        
      in
      (
# 506 "asllib/Parser.mly"
                                                   ( FieldAccess h :: t )
# 7322 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_267 =
    fun expr ->
      (
# 361 "asllib/Parser.mly"
                                    Slice_Single   
# 7330 "asllib/Parser.ml"
       expr : (AST.slice))
  
  let _menhir_action_268 =
    fun _2 e1 e2 ->
      (
# 362 "asllib/Parser.mly"
                                    Slice_Range    
# 7338 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_269 =
    fun _2 e1 e2 ->
      (
# 363 "asllib/Parser.mly"
                                    Slice_Length   
# 7346 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_270 =
    fun _endpos_desc_ _startpos_desc_ desc e ->
      let loc =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7357 "asllib/Parser.ml"
        
      in
      (
# 364 "asllib/Parser.mly"
                                  ( Slice_Length(zero ~loc, e) )
# 7363 "asllib/Parser.ml"
       : (AST.slice))
  
  let _menhir_action_271 =
    fun _2 e1 e2 ->
      (
# 365 "asllib/Parser.mly"
                                    Slice_Star     
# 7371 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_272 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 7379 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_273 =
    fun x ->
      let _1 = 
# 196 "<standard.mly>"
    ( x )
# 7387 "asllib/Parser.ml"
       in
      let _1_1 = _1 in
      (
# 679 "asllib/Parser.mly"
                                             List.concat  
# 7393 "asllib/Parser.ml"
       _1_1 : (AST.t))
  
  let _menhir_action_274 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ e s1 s2 ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 511 "asllib/Parser.mly"
                                                       S_Cond 
# 7406 "asllib/Parser.ml"
         (e, s1, s2) in
        
# 196 "<standard.mly>"
    ( x )
# 7411 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7420 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_275 =
    fun _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ e s1 s2 ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7436 "asllib/Parser.ml"
          
        in
        let x = 
# 511 "asllib/Parser.mly"
                                                       S_Cond 
# 7442 "asllib/Parser.ml"
         (e, s1, s2) in
        
# 196 "<standard.mly>"
    ( x )
# 7447 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7456 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_276 =
    fun _1 _1_inlined1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ expr ->
      let desc =
        let _2 =
          let _1 = _1_inlined2 in
          ()
        in
        let x =
          let alt = _1_inlined1 in
          
# 513 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt (S_Unreachable |> ASTUtils.add_pos_from expr))
# 7471 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7477 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7486 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_277 =
    fun _1 _1_inlined1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ expr ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7502 "asllib/Parser.ml"
          
        in
        let x =
          let alt = _1_inlined1 in
          
# 513 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt (S_Unreachable |> ASTUtils.add_pos_from expr))
# 7510 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7516 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7525 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_278 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr otherwise_stmt ->
      let desc =
        let _2 =
          let _1 = _1_inlined3 in
          ()
        in
        let x =
          let _2 = _2_inlined1 in
          let case_otherwise =
            let _1 = _1_inlined2 in
            
# 493 "asllib/Parser.mly"
      ( otherwise_stmt )
# 7542 "asllib/Parser.ml"
            
          in
          let alt = _1_inlined1 in
          
# 515 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt case_otherwise )
# 7549 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7555 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7564 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_279 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ expr otherwise_stmt ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7580 "asllib/Parser.ml"
          
        in
        let x =
          let _2 = _2_inlined1 in
          let case_otherwise =
            let _1 = _1_inlined2 in
            
# 493 "asllib/Parser.mly"
      ( otherwise_stmt )
# 7590 "asllib/Parser.ml"
            
          in
          let alt = _1_inlined1 in
          
# 515 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt case_otherwise )
# 7597 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7603 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7612 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_280 =
    fun _1 _1_inlined1 _2 _4 _endpos__2_ _startpos__1_ expr loop_limit stmt_list ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 516 "asllib/Parser.mly"
                                                       S_While 
# 7625 "asllib/Parser.ml"
         (expr, loop_limit, stmt_list) in
        
# 196 "<standard.mly>"
    ( x )
# 7630 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7639 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_281 =
    fun _1 _1_inlined1 _4 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ expr loop_limit stmt_list ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7655 "asllib/Parser.ml"
          
        in
        let x = 
# 516 "asllib/Parser.mly"
                                                       S_While 
# 7661 "asllib/Parser.ml"
         (expr, loop_limit, stmt_list) in
        
# 196 "<standard.mly>"
    ( x )
# 7666 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7675 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_282 =
    fun _1 _1_inlined1 _2 _3 _8 _endpos__2_ _startpos__1_ body dir end_e index_name limit start_e ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 519 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 7688 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 7693 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7702 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_283 =
    fun _1 _1_inlined1 _3 _8 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ body dir end_e index_name limit start_e ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7718 "asllib/Parser.ml"
          
        in
        let x = 
# 519 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 7724 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 7729 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7738 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_284 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ c o s ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 520 "asllib/Parser.mly"
                                                                      S_Try  
# 7751 "asllib/Parser.ml"
         (s, c, o) in
        
# 196 "<standard.mly>"
    ( x )
# 7756 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7765 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_285 =
    fun _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ c o s ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7781 "asllib/Parser.ml"
          
        in
        let x = 
# 520 "asllib/Parser.mly"
                                                                      S_Try  
# 7787 "asllib/Parser.ml"
         (s, c, o) in
        
# 196 "<standard.mly>"
    ( x )
# 7792 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7801 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_286 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x = 
# 481 "asllib/Parser.mly"
            ( S_Pass )
# 7810 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 7815 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7824 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_287 =
    fun _1 _2_inlined1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let _2_1 = _2 in
          
# 524 "asllib/Parser.mly"
                                                              S_Return  
# 7836 "asllib/Parser.ml"
           _2_1
        in
        
# 196 "<standard.mly>"
    ( x )
# 7842 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7851 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_288 =
    fun _endpos__2_ _startpos_call_ call ->
      let desc =
        let x = 
# 525 "asllib/Parser.mly"
                                                               s_call  
# 7860 "asllib/Parser.ml"
         call in
        
# 196 "<standard.mly>"
    ( x )
# 7865 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7874 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_289 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let desc =
        let x = 
# 526 "asllib/Parser.mly"
                                                               S_Assert  
# 7883 "asllib/Parser.ml"
         e in
        
# 196 "<standard.mly>"
    ( x )
# 7888 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7897 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_290 =
    fun _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x ->
      let desc =
        let x =
          let _5 = 
# 144 "asllib/Parser.mly"
                        Some 
# 7907 "asllib/Parser.ml"
           x in
          let ty_opt = 
# 123 "<standard.mly>"
    ( None )
# 7912 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 527 "asllib/Parser.mly"
                                                                                 S_Decl    
# 7918 "asllib/Parser.ml"
           (local_decl_keyword_non_var, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 7924 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_local_decl_keyword_non_var_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7933 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_291 =
    fun _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x x_inlined1 ->
      let desc =
        let x =
          let _5 =
            let x = x_inlined1 in
            
# 144 "asllib/Parser.mly"
                        Some 
# 7945 "asllib/Parser.ml"
             x
          in
          let ty_opt = 
# 126 "<standard.mly>"
    ( Some x )
# 7951 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 527 "asllib/Parser.mly"
                                                                                 S_Decl    
# 7957 "asllib/Parser.ml"
           (local_decl_keyword_non_var, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 7963 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_local_decl_keyword_non_var_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7972 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_292 =
    fun _2_inlined1 _endpos__2_ _startpos_le_ e le ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          
# 528 "asllib/Parser.mly"
                                                               S_Assign  
# 7983 "asllib/Parser.ml"
           (le, e)
        in
        
# 196 "<standard.mly>"
    ( x )
# 7989 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_le_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7998 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_293 =
    fun _3 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs setter_access ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8011 "asllib/Parser.ml"
            
          in
          
# 530 "asllib/Parser.mly"
        ( desugar_setter call { access=setter_access; slices=add_dummy_annotation ~version [] } rhs )
# 8017 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8023 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8032 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_294 =
    fun _4 _endpos__2_ _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ desc desc_inlined1 rhs setter_access ->
      let desc =
        let x =
          let slices =
            let (_endpos_desc_, _startpos_desc_, desc) = (_endpos_desc_inlined1_, _startpos_desc_inlined1_, desc_inlined1) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8046 "asllib/Parser.ml"
            
          in
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8055 "asllib/Parser.ml"
            
          in
          
# 532 "asllib/Parser.mly"
        ( desugar_setter call { access=setter_access; slices } rhs )
# 8061 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8067 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8076 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_295 =
    fun _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs x ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let flds = 
# 205 "<standard.mly>"
    ( x )
# 8087 "asllib/Parser.ml"
           in
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8095 "asllib/Parser.ml"
            
          in
          
# 534 "asllib/Parser.mly"
        ( desugar_setter_setfields call flds rhs )
# 8101 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8107 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8116 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_296 =
    fun _4 _endpos__2_ _endpos_desc_ _startpos_desc_ _startpos_ldk_ desc ldk lhs ty ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8129 "asllib/Parser.ml"
            
          in
          
# 536 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs ty call)
# 8135 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8141 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_ldk_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8150 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_297 =
    fun _1 _endpos__2_ _startpos__1_ e ldi ->
      let desc =
        let x =
          let ty = 
# 123 "<standard.mly>"
    ( None )
# 8160 "asllib/Parser.ml"
           in
          
# 537 "asllib/Parser.mly"
                                                              ( S_Decl (LDK_Var, ldi, ty, e) )
# 8165 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8171 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8180 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_298 =
    fun _1 _endpos__2_ _startpos__1_ e ldi x ->
      let desc =
        let x =
          let ty = 
# 126 "<standard.mly>"
    ( Some x )
# 8190 "asllib/Parser.ml"
           in
          
# 537 "asllib/Parser.mly"
                                                              ( S_Decl (LDK_Var, ldi, ty, e) )
# 8195 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8201 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8210 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_299 =
    fun _1 _2_inlined1 _endpos__2_ _startpos__1_ as_ty ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let _2_1 = _2 in
          
# 538 "asllib/Parser.mly"
                                                                make_ldi_vars  
# 8222 "asllib/Parser.ml"
           (_2_1, as_ty)
        in
        
# 196 "<standard.mly>"
    ( x )
# 8228 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8237 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_300 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8250 "asllib/Parser.ml"
            
          in
          
# 540 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs ty call)
# 8256 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8262 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8271 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_301 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 8281 "asllib/Parser.ml"
           in
          
# 541 "asllib/Parser.mly"
                                                              ( S_Print { args; newline = true; debug = false } )
# 8286 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8292 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8301 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_302 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 8311 "asllib/Parser.ml"
           in
          
# 542 "asllib/Parser.mly"
                                                              ( S_Print { args; newline = false; debug = false } )
# 8316 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8322 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8331 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_303 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 8341 "asllib/Parser.ml"
           in
          
# 543 "asllib/Parser.mly"
                                             ( S_Print { args; newline = true; debug = true } )
# 8346 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8352 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8361 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_304 =
    fun _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          
# 544 "asllib/Parser.mly"
                                                             ( S_Unreachable )
# 8372 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8378 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8387 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_305 =
    fun _1 _3 _endpos__2_ _startpos__1_ expr loop_limit stmt_list ->
      let desc =
        let x = 
# 545 "asllib/Parser.mly"
                                                               S_Repeat  
# 8396 "asllib/Parser.ml"
         (stmt_list, expr, loop_limit) in
        
# 196 "<standard.mly>"
    ( x )
# 8401 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8410 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_306 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let desc =
        let x = 
# 546 "asllib/Parser.mly"
                                                             ( S_Throw (Some (e, None)) )
# 8419 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 8424 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8433 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_307 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x = 
# 547 "asllib/Parser.mly"
                                                             ( S_Throw None             )
# 8442 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 8447 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8456 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_308 =
    fun _1 _endpos__2_ _startpos__1_ e x ->
      let desc =
        let x = 
# 548 "asllib/Parser.mly"
                                                                S_Pragma  
# 8465 "asllib/Parser.ml"
         (x, e) in
        
# 196 "<standard.mly>"
    ( x )
# 8470 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8479 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_309 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 552 "asllib/Parser.mly"
                                    stmt_from_list 
# 8488 "asllib/Parser.ml"
       _1_1 : (AST.stmt))
  
  let _menhir_action_310 =
    fun x ->
      (
# 196 "<standard.mly>"
    ( x )
# 8496 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_311 =
    fun _1 _2 ->
      let with_opt = 
# 567 "asllib/Parser.mly"
                ( [] )
# 8504 "asllib/Parser.ml"
       in
      let _2_1 = _2 in
      ((_2_1, with_opt) : (string * AST.field list))
  
  let _menhir_action_312 =
    fun _1 _1_inlined1 _2 fields ->
      let with_opt =
        let _1 = _1_inlined1 in
        fields
      in
      let _2_1 = _2 in
      ((_2_1, with_opt) : (string * AST.field list))
  
  let _menhir_action_313 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 8523 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_314 =
    fun x ->
      (
# 126 "<standard.mly>"
    ( Some x )
# 8531 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_315 =
    fun () ->
      (
# 168 "asllib/Parser.mly"
                  ( [] )
# 8539 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_316 =
    fun _1 ->
      (_1 : (AST.bitfield list))
  
  let _menhir_action_317 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 8551 "asllib/Parser.ml"
       in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 8556 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_318 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 8566 "asllib/Parser.ml"
        
      in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 8572 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_319 =
    fun _2 h t ->
      (
# 173 "asllib/Parser.mly"
                              ( h :: t )
# 8580 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_320 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 8588 "asllib/Parser.ml"
       in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 8593 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_321 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 8603 "asllib/Parser.ml"
        
      in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 8609 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_322 =
    fun _2 h t ->
      (
# 173 "asllib/Parser.mly"
                              ( h :: t )
# 8617 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_323 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 8625 "asllib/Parser.ml"
       in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 8630 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_324 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 8640 "asllib/Parser.ml"
        
      in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 8646 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_325 =
    fun _2 h t ->
      (
# 173 "asllib/Parser.mly"
                              ( h :: t )
# 8654 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_326 =
    fun _1 _endpos_c_ _startpos__1_ c ->
      let desc = 
# 378 "asllib/Parser.mly"
                                                          T_Int         
# 8662 "asllib/Parser.ml"
       c in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_c_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8670 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_327 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 379 "asllib/Parser.mly"
                                                        ( T_Real       )
# 8678 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8686 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_328 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 380 "asllib/Parser.mly"
                                                        ( T_Bool       )
# 8694 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8702 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_329 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 381 "asllib/Parser.mly"
                                                        ( T_String     )
# 8710 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8718 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_330 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let loc =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8730 "asllib/Parser.ml"
          
        in
        
# 382 "asllib/Parser.mly"
                                                        ( t_bit ~loc   )
# 8736 "asllib/Parser.ml"
        
      in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8744 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_331 =
    fun _1 _endpos_bitfields_opt_ _startpos__1_ bitfields_opt x ->
      let desc =
        let _2 = 
# 205 "<standard.mly>"
    ( x )
# 8753 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        
# 383 "asllib/Parser.mly"
                                                          T_Bits        
# 8759 "asllib/Parser.ml"
         (_2_1, bitfields_opt)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_bitfields_opt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8768 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_332 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let l = 
# 205 "<standard.mly>"
    ( x )
# 8777 "asllib/Parser.ml"
         in
        
# 384 "asllib/Parser.mly"
                                                          T_Tuple       
# 8782 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8791 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_333 =
    fun _endpos_name_ _startpos_name_ name ->
      let desc = 
# 385 "asllib/Parser.mly"
                                                          T_Named       
# 8799 "asllib/Parser.ml"
       name in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_name_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8807 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_334 =
    fun _1 _2 _4 _5 _endpos_t_ _startpos__1_ e t ->
      let desc = 
# 386 "asllib/Parser.mly"
                                                        ( T_Array (ArrayLength_Expr e, t) )
# 8815 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_t_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8823 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_335 =
    fun _1 ->
      (_1 : (AST.ty))
  
  let _menhir_action_336 =
    fun _1 _endpos__3_ _startpos__1_ x ->
      let desc =
        let l = 
# 205 "<standard.mly>"
    ( x )
# 8836 "asllib/Parser.ml"
         in
        
# 391 "asllib/Parser.mly"
                                                          T_Enum        
# 8841 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8850 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_337 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 392 "asllib/Parser.mly"
                                                          T_Record      
# 8858 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8866 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_338 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 393 "asllib/Parser.mly"
                                                          T_Exception   
# 8874 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8882 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_339 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 394 "asllib/Parser.mly"
                                                          T_Collection  
# 8890 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8898 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_340 =
    fun x y ->
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 8906 "asllib/Parser.ml"
       : (AST.field))
  
  let _menhir_action_341 =
    fun i ->
      (
# 201 "asllib/Parser.mly"
                        L_Int          
# 8914 "asllib/Parser.ml"
       i : (AST.literal))
  
  let _menhir_action_342 =
    fun b ->
      (
# 202 "asllib/Parser.mly"
                        L_Bool         
# 8922 "asllib/Parser.ml"
       b : (AST.literal))
  
  let _menhir_action_343 =
    fun r ->
      (
# 203 "asllib/Parser.mly"
                        L_Real         
# 8930 "asllib/Parser.ml"
       r : (AST.literal))
  
  let _menhir_action_344 =
    fun b ->
      (
# 204 "asllib/Parser.mly"
                        L_BitVector    
# 8938 "asllib/Parser.ml"
       b : (AST.literal))
  
  let _menhir_action_345 =
    fun s ->
      (
# 205 "asllib/Parser.mly"
                        L_String       
# 8946 "asllib/Parser.ml"
       s : (AST.literal))
  
  let _menhir_print_token : token -> string =
    fun _tok ->
      match _tok with
      | Tokens.ACCESSOR ->
          "ACCESSOR"
      | Tokens.AND ->
          "AND"
      | Tokens.ARBITRARY ->
          "ARBITRARY"
      | Tokens.ARRAY ->
          "ARRAY"
      | Tokens.ARROW ->
          "ARROW"
      | Tokens.AS ->
          "AS"
      | Tokens.ASSERT ->
          "ASSERT"
      | Tokens.BAND ->
          "BAND"
      | Tokens.BEGIN ->
          "BEGIN"
      | Tokens.BEQ ->
          "BEQ"
      | Tokens.BIARROW ->
          "BIARROW"
      | Tokens.BIT ->
          "BIT"
      | Tokens.BITS ->
          "BITS"
      | Tokens.BITVECTOR_LIT _ ->
          "BITVECTOR_LIT"
      | Tokens.BNOT ->
          "BNOT"
      | Tokens.BOOLEAN ->
          "BOOLEAN"
      | Tokens.BOOL_LIT _ ->
          "BOOL_LIT"
      | Tokens.BOR ->
          "BOR"
      | Tokens.CASE ->
          "CASE"
      | Tokens.CATCH ->
          "CATCH"
      | Tokens.COLLECTION ->
          "COLLECTION"
      | Tokens.COLON ->
          "COLON"
      | Tokens.COLON_COLON ->
          "COLON_COLON"
      | Tokens.COMMA ->
          "COMMA"
      | Tokens.CONFIG ->
          "CONFIG"
      | Tokens.CONSTANT ->
          "CONSTANT"
      | Tokens.DEBUG ->
          "DEBUG"
      | Tokens.DIV ->
          "DIV"
      | Tokens.DIVRM ->
          "DIVRM"
      | Tokens.DO ->
          "DO"
      | Tokens.DOT ->
          "DOT"
      | Tokens.DOWNTO ->
          "DOWNTO"
      | Tokens.ELSE ->
          "ELSE"
      | Tokens.ELSIF ->
          "ELSIF"
      | Tokens.END ->
          "END"
      | Tokens.ENUMERATION ->
          "ENUMERATION"
      | Tokens.EOF ->
          "EOF"
      | Tokens.EQ ->
          "EQ"
      | Tokens.EQ_OP ->
          "EQ_OP"
      | Tokens.EXCEPTION ->
          "EXCEPTION"
      | Tokens.FOR ->
          "FOR"
      | Tokens.FUNC ->
          "FUNC"
      | Tokens.GEQ ->
          "GEQ"
      | Tokens.GETTER ->
          "GETTER"
      | Tokens.GT ->
          "GT"
      | Tokens.IDENTIFIER _ ->
          "IDENTIFIER"
      | Tokens.IF ->
          "IF"
      | Tokens.IMPDEF ->
          "IMPDEF"
      | Tokens.IMPL ->
          "IMPL"
      | Tokens.IMPLEMENTATION ->
          "IMPLEMENTATION"
      | Tokens.IN ->
          "IN"
      | Tokens.INTEGER ->
          "INTEGER"
      | Tokens.INT_LIT _ ->
          "INT_LIT"
      | Tokens.LBRACE ->
          "LBRACE"
      | Tokens.LBRACKET ->
          "LBRACKET"
      | Tokens.LEQ ->
          "LEQ"
      | Tokens.LET ->
          "LET"
      | Tokens.LLBRACKET ->
          "LLBRACKET"
      | Tokens.LOOPLIMIT ->
          "LOOPLIMIT"
      | Tokens.LPAR ->
          "LPAR"
      | Tokens.LT ->
          "LT"
      | Tokens.MASK_LIT _ ->
          "MASK_LIT"
      | Tokens.MINUS ->
          "MINUS"
      | Tokens.MOD ->
          "MOD"
      | Tokens.MUL ->
          "MUL"
      | Tokens.NEQ ->
          "NEQ"
      | Tokens.NOT ->
          "NOT"
      | Tokens.OF ->
          "OF"
      | Tokens.OR ->
          "OR"
      | Tokens.OTHERWISE ->
          "OTHERWISE"
      | Tokens.PASS ->
          "PASS"
      | Tokens.PLUS ->
          "PLUS"
      | Tokens.PLUS_COLON ->
          "PLUS_COLON"
      | Tokens.POW ->
          "POW"
      | Tokens.PRAGMA ->
          "PRAGMA"
      | Tokens.PRINT ->
          "PRINT"
      | Tokens.PRINTLN ->
          "PRINTLN"
      | Tokens.RBRACE ->
          "RBRACE"
      | Tokens.RBRACKET ->
          "RBRACKET"
      | Tokens.RDIV ->
          "RDIV"
      | Tokens.REAL ->
          "REAL"
      | Tokens.REAL_LIT _ ->
          "REAL_LIT"
      | Tokens.RECORD ->
          "RECORD"
      | Tokens.RECURSELIMIT ->
          "RECURSELIMIT"
      | Tokens.REPEAT ->
          "REPEAT"
      | Tokens.RETURN ->
          "RETURN"
      | Tokens.RPAR ->
          "RPAR"
      | Tokens.RRBRACKET ->
          "RRBRACKET"
      | Tokens.SEMI_COLON ->
          "SEMI_COLON"
      | Tokens.SETTER ->
          "SETTER"
      | Tokens.SHL ->
          "SHL"
      | Tokens.SHR ->
          "SHR"
      | Tokens.SLICING ->
          "SLICING"
      | Tokens.STAR_COLON ->
          "STAR_COLON"
      | Tokens.STRING ->
          "STRING"
      | Tokens.STRING_LIT _ ->
          "STRING_LIT"
      | Tokens.SUBTYPES ->
          "SUBTYPES"
      | Tokens.THEN ->
          "THEN"
      | Tokens.THROW ->
          "THROW"
      | Tokens.TO ->
          "TO"
      | Tokens.TRY ->
          "TRY"
      | Tokens.TYPE ->
          "TYPE"
      | Tokens.UNREACHABLE ->
          "UNREACHABLE"
      | Tokens.UNTIL ->
          "UNTIL"
      | Tokens.VAR ->
          "VAR"
      | Tokens.WHEN ->
          "WHEN"
      | Tokens.WHERE ->
          "WHERE"
      | Tokens.WHILE ->
          "WHILE"
      | Tokens.WITH ->
          "WITH"
      | Tokens.XOR ->
          "XOR"
  
  let _menhir_fail : unit -> 'a =
    fun () ->
      Printf.eprintf "Internal failure -- please contact the parser generator's developers.\n%!";
      assert false
  
  include struct
    
    [@@@ocaml.warning "-4-37"]
    
    let _menhir_run_557 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let (_2, body) = ((), _v) in
            let _v = _menhir_action_235 _2 body in
            MenhirBox_opn _v
        | _ ->
            _eRR ()
    
    let _menhir_run_756 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let x = _v in
            let _v = _menhir_action_310 x in
            MenhirBox_stmts _v
        | _ ->
            _eRR ()
    
    let _menhir_run_743 : type  ttv_stack. ttv_stack -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let x = _v in
        let _v = _menhir_action_273 x in
        MenhirBox_spec _v
    
    let rec _menhir_run_753 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_decl -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_decl (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_222 x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_goto_list_decl_ : type  ttv_stack. ttv_stack -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _v _menhir_s ->
        match _menhir_s with
        | MenhirState752 ->
            _menhir_run_753 _menhir_stack _v
        | MenhirState560 ->
            _menhir_run_743 _menhir_stack _v
        | _ ->
            _menhir_fail ()
    
    let rec _menhir_run_001 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState001 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_002 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_345 s in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_goto_value : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState454 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState748 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState728 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState642 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState610 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState566 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState530 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState498 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState471 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState467 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState459 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState451 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState446 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState441 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState437 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState416 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState393 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState384 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState379 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState374 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState368 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState339 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState349 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState343 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState334 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState310 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState279 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState268 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState266 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState033 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState248 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState243 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState241 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState239 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState237 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState235 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState233 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState225 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState223 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState219 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState214 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState211 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState209 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState207 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState205 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState203 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState200 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState198 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState194 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState192 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState190 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState188 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState116 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState052 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState031 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState029 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState025 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_177 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_value_, _startpos_value_, value) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_160 _endpos_value_ _startpos_value_ value in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_value_ _startpos_value_ _v _menhir_s _tok
    
    and _menhir_goto_expr_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState055 ->
            _menhir_run_258 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState454 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_258 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_186 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_201 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_221 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_225 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_228 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_233 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_235 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_237 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_239 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_241 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_243 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_245 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_248 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.COMMA ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_248 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_184 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_XOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState184 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_003 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_r_, _startpos_r_, r) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_343 r in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_r_ _v _menhir_s _tok
    
    and _menhir_run_004 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState004 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_005 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState005 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_006 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState006 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_007 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_i_, _startpos_i_, i) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_341 i in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_i_ _startpos_i_ _v _menhir_s _tok
    
    and _menhir_run_008 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState008 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_009 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState009
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState009
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_116 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_010 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.RPAR ->
            let _v = _menhir_action_030 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_011 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_342 b in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_012 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState012 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_013 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_344 b in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_014 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState015 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_016 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_329 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_ty : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState639 ->
            _menhir_run_640 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState587 ->
            _menhir_run_606 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState536 ->
            _menhir_run_542 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState538 ->
            _menhir_run_539 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState015 ->
            _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState289 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState245 ->
            _menhir_run_246 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState175 ->
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState100 ->
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState113 ->
            _menhir_run_121 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState119 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_640 : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_ARROW -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ARROW (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _2) = ((), _v) in
        let _v = _menhir_action_261 _1 _2 in
        _menhir_goto_return_type _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_return_type : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState713 ->
            _menhir_run_718 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState688 ->
            _menhir_run_693 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState633 ->
            _menhir_run_641 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_718 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_642 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_259 () in
            _menhir_run_719 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState718
        | _ ->
            _eRR ()
    
    and _menhir_run_642 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RECURSELIMIT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState642 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_719 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState720
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState720
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_234 _endpos__0_
            in
            _menhir_run_721 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_314 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState314
        | Tokens.LPAR ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState314
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState314, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState328 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON | Tokens.EQ | Tokens.SEMI_COLON ->
                let _v =
                  let _1 = _v in
                  _menhir_action_099 _1
                in
                _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState314 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_315 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_098 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_decl_item : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState464 ->
            _menhir_run_466 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState314 ->
            _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_466 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState466) in
            let _menhir_s = MenhirState467 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState466
        | _ ->
            _eRR ()
    
    and _menhir_run_113 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState113 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_017 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_327 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_018 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState018 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RPAR ->
            let _v = _menhir_action_032 () in
            _menhir_goto_clist0_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_019 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState019 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let _v = _menhir_action_072 () in
            _menhir_goto_constraint_kind_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_020 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.MINUS ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.RBRACE ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_startpos__1_, x, _endpos__3_) = (_startpos, (), _endpos_1) in
                let _v = _menhir_action_070 x in
                _menhir_goto_constraint_kind _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | _ ->
                _eRR ())
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | _ ->
            _eRR ()
    
    and _menhir_goto_constraint_kind : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState019 ->
            _menhir_run_287 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState245 ->
            _menhir_run_247 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState100 ->
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_287 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_INTEGER -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_071 _1 in
        _menhir_goto_constraint_kind_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
    
    and _menhir_goto_constraint_kind_opt : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_INTEGER -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_c_, c) = ((), _endpos, _v) in
        let _v = _menhir_action_326 _1 _endpos_c_ _startpos__1_ c in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _menhir_s _tok
    
    and _menhir_run_247 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_constraint_kind_, _startpos_constraint_kind_, constraint_kind) = ((), _endpos, _startpos, _v) in
        let _v = _menhir_action_196 _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_pattern_ constraint_kind expr_pattern in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_constraint_kind_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_130 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_constraint_kind_, _startpos_constraint_kind_, constraint_kind) = ((), _endpos, _startpos, _v) in
        let _v = _menhir_action_151 _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_ constraint_kind expr in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_constraint_kind_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_goto_expr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState748 ->
            _menhir_run_749 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState728 ->
            _menhir_run_729 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState642 ->
            _menhir_run_643 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState566 ->
            _menhir_run_567 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState530 ->
            _menhir_run_531 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState498 ->
            _menhir_run_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_488 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState471 ->
            _menhir_run_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState467 ->
            _menhir_run_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState459 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState451 ->
            _menhir_run_452 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState441 ->
            _menhir_run_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState437 ->
            _menhir_run_438 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState393 ->
            _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState368 ->
            _menhir_run_371 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState339 ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState334 ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState310 ->
            _menhir_run_311 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_309 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_300 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_298 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_295 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_282 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState279 ->
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState268 ->
            _menhir_run_269 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState033 ->
            _menhir_run_267 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState266 ->
            _menhir_run_267 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_254 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState248 ->
            _menhir_run_249 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState243 ->
            _menhir_run_244 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState241 ->
            _menhir_run_242 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState239 ->
            _menhir_run_240 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState237 ->
            _menhir_run_238 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState235 ->
            _menhir_run_236 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState233 ->
            _menhir_run_234 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState225 ->
            _menhir_run_227 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState223 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_222 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState219 ->
            _menhir_run_220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState214 ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState211 ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState209 ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState207 ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState205 ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState203 ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState200 ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState198 ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState194 ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState192 ->
            _menhir_run_193 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState190 ->
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState188 ->
            _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_185 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState610 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState446 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState416 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState384 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState379 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState374 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState349 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState343 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState116 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState052 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState031 ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState029 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState025 ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_749 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_option_as_ty_ (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_global_let_or_constant (_menhir_stack, _menhir_s, keyword, _startpos_keyword_) = _menhir_stack in
            let (_endpos__2_, x, _4) = (_endpos_0, _v, ()) in
            let _v = _menhir_action_087 _4 _endpos__2_ _startpos_keyword_ keyword name ty x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState749
        | _ ->
            _eRR ()
    
    and _menhir_run_027 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_XOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState027 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_029 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState029 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_036 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState036 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_decl : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_561 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.TYPE ->
            _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.PRAGMA ->
            _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.LET ->
            _menhir_run_613 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.IMPLEMENTATION ->
            _menhir_run_614 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.IMPDEF ->
            _menhir_run_684 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.FUNC ->
            _menhir_run_710 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.CONSTANT ->
            _menhir_run_724 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.CONFIG ->
            _menhir_run_725 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.ACCESSOR ->
            _menhir_run_731 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.EOF ->
            let _v_0 = _menhir_action_221 () in
            _menhir_run_753 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_561 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState561 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_562 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_563 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_562 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_212 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ignored_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_ignored_or_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState745 ->
            _menhir_run_746 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState725 ->
            _menhir_run_726 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState561 ->
            _menhir_run_564 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_746 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
        | Tokens.EQ ->
            let _v_0 = _menhir_action_238 () in
            _menhir_run_747 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState746 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_747 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_option_as_ty_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState748 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_726 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
        | _ ->
            _eRR ()
    
    and _menhir_run_564 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState564
        | Tokens.EQ ->
            let _v_0 = _menhir_action_238 () in
            _menhir_run_565 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState564 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_565 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_option_as_ty_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState566 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_563 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = _v in
        let _v = _menhir_action_213 _1 in
        _menhir_goto_ignored_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_571 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SUBTYPES ->
                _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState572
            | Tokens.OF ->
                let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState572) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | Tokens.RECORD ->
                    let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_RECORD (_menhir_stack, MenhirState587, _startpos_1) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_576 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState588
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_3 = _menhir_action_207 () in
                        _menhir_run_589 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_2 _v_3 _tok
                    | _ ->
                        _eRR ())
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | Tokens.IDENTIFIER _v_4 ->
                    _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState587
                | Tokens.EXCEPTION ->
                    let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_EXCEPTION (_menhir_stack, MenhirState587, _startpos_5) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_576 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState591
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_7 = _menhir_action_207 () in
                        _menhir_run_592 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_6 _v_7 _tok
                    | _ ->
                        _eRR ())
                | Tokens.ENUMERATION ->
                    let _menhir_s = MenhirState587 in
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _menhir_stack = MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
                        let _menhir_s = MenhirState594 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_595 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.COLLECTION ->
                    let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_COLLECTION (_menhir_stack, MenhirState587, _startpos_11) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_576 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState600
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_13 = _menhir_action_207 () in
                        _menhir_run_601 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_12 _v_13 _tok
                    | _ ->
                        _eRR ())
                | Tokens.BOOLEAN ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | Tokens.BITS ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | Tokens.BIT ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | Tokens.ARRAY ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState587
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_573 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WITH ->
                let _menhir_stack = MenhirCell1_SUBTYPES (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState575 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_576 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let (_startpos__1_, _1, _endpos__2_, _2) = (_startpos, (), _endpos, _v) in
                let _v = _menhir_action_311 _1 _2 in
                _menhir_goto_subtype _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _startpos__1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_576 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RBRACE ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (x, _endpos__3_) = ((), _endpos_1) in
                let _v = _menhir_action_205 x in
                _menhir_goto_fields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_579 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState576
        | _ ->
            _eRR ()
    
    and _menhir_goto_fields : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState600 ->
            _menhir_run_590 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState591 ->
            _menhir_run_590 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState588 ->
            _menhir_run_590 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState575 ->
            _menhir_run_586 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_590 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_208 _1 in
        _menhir_goto_fields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_fields_opt : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState600 ->
            _menhir_run_601 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState591 ->
            _menhir_run_592 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState588 ->
            _menhir_run_589 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_601 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_COLLECTION -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_COLLECTION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_339 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_ty_decl : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SUBTYPES ->
            _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
        | Tokens.SEMI_COLON ->
            let _v = _menhir_action_313 () in
            _menhir_goto_subtype_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_subtype_opt : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ty_decl (_menhir_stack, _, t) = _menhir_stack in
            let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3, subtype_opt) = ((), _endpos, (), _v) in
            let _v = _menhir_action_085 _1 _3 _endpos__2_ _startpos__1_ subtype_opt t x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_592 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_EXCEPTION -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_EXCEPTION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_338 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_589 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_RECORD -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RECORD (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_337 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_586 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_SUBTYPES _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2, _, _) = _menhir_stack in
        let MenhirCell1_SUBTYPES (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined1, _endpos_fields_, fields) = ((), (), _endpos, _v) in
        let _v = _menhir_action_312 _1 _1_inlined1 _2 fields in
        _menhir_goto_subtype _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_fields_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_subtype : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState572 ->
            _menhir_run_607 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState602 ->
            _menhir_run_605 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_607 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc) = ((), _endpos_0, _endpos, _startpos, _v) in
            let _v = _menhir_action_086 _1 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_605 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let x = _v in
        let _v = _menhir_action_314 x in
        _menhir_goto_subtype_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_run_579 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState579 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_101 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_333 _endpos_name_ _startpos_name_ name in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_name_ _v _menhir_s _tok
    
    and _menhir_run_595 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                _menhir_run_595 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState596
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_318 x x_inlined1 in
                _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_317 x in
            _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_IDENTIFIER_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState594 ->
            _menhir_run_598 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState596 ->
            _menhir_run_597 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_598 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_336 _1 _endpos__3_ _startpos__1_ x in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_597 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_319 _2 h t in
        _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_102 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_328 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_103 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState104 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_114 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_330 _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_115 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_s = MenhirState116 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_609 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState610
            | Tokens.REAL_LIT _v_2 ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState610
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
            | Tokens.INT_LIT _v_3 ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState610
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
            | Tokens.IDENTIFIER _v_4 ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState610
            | Tokens.BOOL_LIT _v_5 ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState610
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
            | Tokens.BITVECTOR_LIT _v_6 ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState610
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
            | Tokens.SEMI_COLON ->
                let _v_7 = _menhir_action_030 () in
                _menhir_run_611 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_611 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_091 _1 _endpos__2_ _startpos__1_ e x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_613 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_210 _1 in
        _menhir_goto_global_let_or_constant _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_global_let_or_constant : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_global_let_or_constant (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_562 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState745
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_563 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState745
        | _ ->
            _eRR ()
    
    and _menhir_run_614 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.FUNC ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_1, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState616
                | Tokens.LPAR ->
                    let _v_2 = _menhir_action_246 () in
                    _menhir_run_625 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState616 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.ACCESSOR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_3, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState650
                | Tokens.LPAR ->
                    let _v_4 = _menhir_action_246 () in
                    _menhir_run_651 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState650 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_617 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState617 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_618 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState618
        | Tokens.COMMA | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_236 x in
            _menhir_goto_opt_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_opt_typed_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_opt_typed_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState621 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_052 x in
            _menhir_goto_clist1_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_opt_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState617 ->
            _menhir_run_623 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState621 ->
            _menhir_run_622 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_623 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_247 x in
        _menhir_goto_params_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_params_opt : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState732 ->
            _menhir_run_733 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState711 ->
            _menhir_run_712 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState700 ->
            _menhir_run_701 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState686 ->
            _menhir_run_687 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState650 ->
            _menhir_run_651 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState616 ->
            _menhir_run_625 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_733 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState733
        | _ ->
            _eRR ()
    
    and _menhir_run_626 : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState626 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_579 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.RPAR ->
            let _v = _menhir_action_034 () in
            _menhir_goto_clist0_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist0_typed_identifier_ : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_209 x in
        _menhir_goto_func_args _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_func_args : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState733 ->
            _menhir_run_734 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_713 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState701 ->
            _menhir_run_702 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_688 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState651 ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState625 ->
            _menhir_run_633 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_734 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BIARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState736 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_713 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState713) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState714
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState714
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_234 _endpos__0_
                in
                _menhir_run_715 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState713
        | _ ->
            _eRR ()
    
    and _menhir_run_359 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RPAR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SEMI_COLON ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_startpos__1_, _1, _endpos__2_, _3, _2_inlined1) = (_startpos, (), _endpos_1, (), ()) in
                    let _v = _menhir_action_304 _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ in
                    _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_stmt : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState000 ->
            _menhir_run_557 _menhir_stack _v _tok
        | MenhirState754 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState720 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState714 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState695 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState689 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState677 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState672 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState665 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState645 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState363 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState547 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState543 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState540 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState372 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_463 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.PRINTLN ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState463
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_227 x in
            _menhir_goto_list1_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_363 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState363 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_364 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
            let _v = _menhir_action_307 _1 _endpos__2_ _startpos__1_ in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | _ ->
            _eRR ()
    
    and _menhir_run_368 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState368 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.SEMI_COLON ->
            let _v = _menhir_action_240 () in
            _menhir_goto_option_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_option_expr_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_RETURN -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos__2_, _2_inlined1) = ((), _endpos, _v) in
        let _v = _menhir_action_287 _1 _2_inlined1 _endpos__2_ _startpos__1_ in
        _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_run_372 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState372 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_373 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRINTLN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState374
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState374
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState374
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState374
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState374
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState374
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState374
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState374
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState374
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState374
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState374
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState374
            | Tokens.RPAR ->
                let _v = _menhir_action_030 () in
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_375 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRINTLN _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PRINTLN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_301 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_378 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState379
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState379
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState379
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState379
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState379
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState379
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState379
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState379
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState379
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState379
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState379
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState379
            | Tokens.RPAR ->
                let _v = _menhir_action_030 () in
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_380 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRINT _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_302 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_383 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState384
            | Tokens.REAL_LIT _v_2 ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState384
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState384
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState384
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState384
            | Tokens.INT_LIT _v_3 ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState384
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState384
            | Tokens.IDENTIFIER _v_4 ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState384
            | Tokens.BOOL_LIT _v_5 ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState384
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState384
            | Tokens.BITVECTOR_LIT _v_6 ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState384
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState384
            | Tokens.SEMI_COLON ->
                let _v_7 = _menhir_action_030 () in
                _menhir_run_385 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_385 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_308 _1 _endpos__2_ _startpos__1_ e x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_387 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
            let _v = _menhir_action_286 _1 _endpos__2_ _startpos__1_ in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_389 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_218 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState478 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_390 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState390 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_391 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_103 _1 in
        _menhir_goto_discard_or_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_basic_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState405 ->
            _menhir_run_404 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState403 ->
            _menhir_run_404 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState390 ->
            _menhir_run_402 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_404 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_basic_lexpr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState405 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_040 x in
            _menhir_goto_clist1_discard_or_basic_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_392 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState392
        | Tokens.DOT ->
            _menhir_run_396 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState392
        | Tokens.COMMA | Tokens.LBRACKET | Tokens.RPAR ->
            let _v_0 = _menhir_action_003 () in
            _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState392 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_393 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState393 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_396 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_397 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState397
        | Tokens.DOT ->
            _menhir_run_396 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState397
        | Tokens.COMMA | Tokens.EQ | Tokens.LBRACKET | Tokens.RPAR ->
            let _v_0 = _menhir_action_003 () in
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_398 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, t) = ((), _v) in
        let _v = _menhir_action_004 _1 _endpos_desc_ _startpos_desc_ desc t in
        _menhir_goto_access _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_access : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState415 ->
            _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState392 ->
            _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState395 ->
            _menhir_run_399 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState397 ->
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_400 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_access (_menhir_stack, _menhir_s, _v) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState400
        | Tokens.COMMA | Tokens.EQ | Tokens.RPAR ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let access = _v in
            let _v = _menhir_action_015 _endpos_desc_ _startpos_desc_ access desc in
            _menhir_goto_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_033 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState033 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.COLON ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_034 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState034 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_basic_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState754 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState720 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState714 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState695 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState689 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState677 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState672 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState665 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState645 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState363 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState547 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState543 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState540 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState372 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState390 ->
            _menhir_run_407 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState403 ->
            _menhir_run_407 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState405 ->
            _menhir_run_407 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_501 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let (_startpos_basic_lexpr_, basic_lexpr) = (_startpos, _v) in
        let _v = _menhir_action_216 basic_lexpr in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_basic_lexpr_ _v _menhir_s _tok
    
    and _menhir_run_407 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let basic_lexpr = _v in
        let _v = _menhir_action_104 basic_lexpr in
        _menhir_goto_discard_or_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_399 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LLBRACKET, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RRBRACKET -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_RRBRACKET (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, idx, _, _) = _menhir_stack in
        let MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _3, t) = ((), (), _v) in
        let _v = _menhir_action_005 _1 _3 idx t in
        _menhir_goto_access _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_basic_lexpr_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_basic_lexpr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState403 ->
            _menhir_run_408 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState405 ->
            _menhir_run_406 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_408 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_discard_or_basic_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_064 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_217 _endpos__3_ _startpos__1_ x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_406 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_basic_lexpr, ttv_result) _menhir_cell1_discard_or_basic_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_041 _2 h t in
        _menhir_goto_clist1_discard_or_basic_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_402 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState403 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_411 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_229 _1 in
        _menhir_goto_local_decl_keyword_non_var _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_local_decl_keyword_non_var : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState464
        | Tokens.LPAR ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState464
        | Tokens.IDENTIFIER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v_2 =
              let _1 = _v_0 in
              _menhir_action_099 _1
            in
            _menhir_run_466 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState464 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_316 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState316 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_317 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_107 _1 in
        _menhir_goto_discard_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_identifier : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState322 ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState320 ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState316 ->
            _menhir_run_319 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_321 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState322 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_044 x in
            _menhir_goto_clist1_discard_or_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_318 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = _v in
        let _v = _menhir_action_108 _1 in
        _menhir_goto_discard_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_identifier_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState320 ->
            _menhir_run_324 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState322 ->
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_324 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_discard_or_identifier -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_identifier (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_066 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_100 _endpos__3_ _startpos__1_ x in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_323 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier, ttv_result) _menhir_cell1_discard_or_identifier -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_045 _2 h t in
        _menhir_goto_clist1_discard_or_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_319 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState320 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_412 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState412 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_415 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState415
        | Tokens.LLBRACKET ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState415
        | Tokens.LBRACE ->
            let _menhir_s = MenhirState415 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState416 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, MenhirState415) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState418 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.MINUS ->
                    _menhir_run_419 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.LBRACKET ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState429 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | Tokens.EQ | Tokens.LBRACKET ->
            let _v_12 = _menhir_action_003 () in
            _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState415 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_419 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_105 _1 in
        _menhir_goto_discard_or_field _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_field : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState424 ->
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState422 ->
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState418 ->
            _menhir_run_421 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_423 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState424 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_419 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_042 x in
            _menhir_goto_clist1_discard_or_field_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_420 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_106 _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_discard_or_field _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_field_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState422 ->
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState424 ->
            _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_426 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_discard_or_field -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_field (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_065 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_220 _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_425 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field, ttv_result) _menhir_cell1_discard_or_field -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_043 _2 h t in
        _menhir_goto_clist1_discard_or_field_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_421 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState422 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_419 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_430 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState431 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_044 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState045 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACKET ->
            let x = _v in
            let _v = _menhir_action_036 x in
            _menhir_goto_clist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_IDENTIFIER_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState431 ->
            _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState229 ->
            _menhir_run_230 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState043 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState045 ->
            _menhir_run_046 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_432 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_062 _2 li x in
        _menhir_goto_clist2_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_goto_clist2_IDENTIFIER_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState484 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState429 ->
            _menhir_run_433 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_485 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState487 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_433 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_219 _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_230 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_194 _2 _endpos__3_ _startpos_e_ e x in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_047 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_149 _2 _endpos__3_ _startpos_e_ e x in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_046 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_037 _2 h t in
        _menhir_goto_clist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_435 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState437 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_445 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState446
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState446
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState446
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState446
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState446
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState446
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState446
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState446
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState446
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState446
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState446
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState446
            | Tokens.RPAR ->
                let _v = _menhir_action_030 () in
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_447 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DEBUG _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_303 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_450 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_230 _1 in
        _menhir_goto_local_decl_keyword_non_var _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_451 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState451 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_459 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState459 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_list1_stmt_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState754 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState720 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState714 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState695 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState689 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState677 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState672 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState665 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState645 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState363 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState547 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState543 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState540 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState372 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_502 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_309 _1 in
        _menhir_goto_stmt_list _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_stmt_list : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState754 ->
            _menhir_run_756 _menhir_stack _v _tok
        | MenhirState720 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState714 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState695 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState689 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState677 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState672 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState665 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState645 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_554 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState547 ->
            _menhir_run_548 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState543 ->
            _menhir_run_544 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState540 ->
            _menhir_run_541 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState363 ->
            _menhir_run_534 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState372 ->
            _menhir_run_529 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState521 ->
            _menhir_run_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_515 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState507 ->
            _menhir_run_508 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState503 ->
            _menhir_run_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState458 ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_635 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_233 _1 in
        _menhir_goto_maybe_empty_stmt_list _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_maybe_empty_stmt_list : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState720 ->
            _menhir_run_721 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState714 ->
            _menhir_run_715 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState695 ->
            _menhir_run_696 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState689 ->
            _menhir_run_690 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState677 ->
            _menhir_run_678 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState672 ->
            _menhir_run_673 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState669 ->
            _menhir_run_670 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState665 ->
            _menhir_run_666 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState661 ->
            _menhir_run_662 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState657 ->
            _menhir_run_658 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState645 ->
            _menhir_run_646 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState634 ->
            _menhir_run_636 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_721 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined1) = ((), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_073 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = ((), _v, _endpos, _startpos, ()) in
                let _v = _menhir_action_074 _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_715 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined1) = ((), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_079 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = ((), _v, _endpos, _startpos, ()) in
                let _v = _menhir_action_080 _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_696 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_075 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_076 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_690 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_081 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_082 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_678 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _4, _1_inlined1, _1_inlined2, setter) = ((), (), (), (), (), (), _v) in
                let _v = _menhir_action_006 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, setter) = ((), (), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_007 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_accessors : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState738 ->
            _menhir_run_739 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState706 ->
            _menhir_run_707 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState656 ->
            _menhir_run_681 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_739 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, accessors, _6) = ((), (), (), (), _v, ()) in
                let _v = _menhir_action_092 _1 _1_inlined1 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, accessors, _6) = ((), (), _endpos, _startpos, (), _v, ()) in
                let _v = _menhir_action_093 _1 _1_inlined1 _2 _6 _endpos__1_inlined1_ _startpos__1_inlined1_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_707 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, _1_inlined2, accessors, _6) = ((), (), (), (), (), _v, ()) in
                let _v = _menhir_action_094 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, accessors, _6) = ((), (), (), (), _endpos, _startpos, _v, ()) in
                let _v = _menhir_action_095 _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_681 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, _1_inlined2, accessors, _6) = ((), (), (), (), (), _v, ()) in
                let _v = _menhir_action_096 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, accessors, _6) = ((), (), (), (), _endpos, _startpos, _v, ()) in
                let _v = _menhir_action_097 _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_673 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, setter) = ((), (), (), (), (), _v) in
                let _v = _menhir_action_008 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, setter) = ((), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_009 _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_670 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_END (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.UNREACHABLE ->
                    _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.TRY ->
                    _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.THROW ->
                    _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.RETURN ->
                    _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.REPEAT ->
                    _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.PRINTLN ->
                    _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.PRINT ->
                    _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.PRAGMA ->
                    _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.PASS ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.MINUS ->
                    _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.LPAR ->
                    _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.LET ->
                    _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.IF ->
                    _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.IDENTIFIER _v_1 ->
                    _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState672
                | Tokens.FOR ->
                    _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.DEBUG ->
                    _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.CONSTANT ->
                    _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.CASE ->
                    _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.ASSERT ->
                    _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState672
                | Tokens.END ->
                    let _v_2 =
                      let _endpos__0_ = _endpos_0 in
                      _menhir_action_234 _endpos__0_
                    in
                    _menhir_run_673 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 _tok
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SETTER ->
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.VAR ->
                        _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.UNREACHABLE ->
                        _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.TRY ->
                        _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.THROW ->
                        _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.RETURN ->
                        _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.REPEAT ->
                        _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.PRINTLN ->
                        _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.PRINT ->
                        _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.PRAGMA ->
                        _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.PASS ->
                        _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.MINUS ->
                        _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.LPAR ->
                        _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.LET ->
                        _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.IF ->
                        _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.IDENTIFIER _v_5 ->
                        _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState677
                    | Tokens.FOR ->
                        _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.DEBUG ->
                        _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.CONSTANT ->
                        _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.CASE ->
                        _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.ASSERT ->
                        _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState677
                    | Tokens.END ->
                        let _v_6 =
                          let _endpos__0_ = _endpos_4 in
                          _menhir_action_234 _endpos__0_
                        in
                        _menhir_run_678 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_666 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, getter) = ((), (), (), (), (), _v) in
                let _v = _menhir_action_012 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, getter) = ((), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_013 _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_662 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _4, _1_inlined1, _1_inlined2, getter) = ((), (), (), (), (), (), _v) in
                let _v = _menhir_action_010 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, getter) = ((), (), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_011 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_658 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_END (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.GETTER ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.VAR ->
                        _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.UNREACHABLE ->
                        _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.TRY ->
                        _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.THROW ->
                        _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.RETURN ->
                        _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.REPEAT ->
                        _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.PRINTLN ->
                        _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.PRINT ->
                        _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.PRAGMA ->
                        _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.PASS ->
                        _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.MINUS ->
                        _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.LPAR ->
                        _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.LET ->
                        _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.IF ->
                        _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.IDENTIFIER _v_2 ->
                        _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState661
                    | Tokens.FOR ->
                        _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.DEBUG ->
                        _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.CONSTANT ->
                        _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.CASE ->
                        _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.ASSERT ->
                        _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
                    | Tokens.END ->
                        let _v_3 =
                          let _endpos__0_ = _endpos_1 in
                          _menhir_action_234 _endpos__0_
                        in
                        _menhir_run_662 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.GETTER ->
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.UNREACHABLE ->
                    _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.TRY ->
                    _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.THROW ->
                    _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.RETURN ->
                    _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.REPEAT ->
                    _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.PRINTLN ->
                    _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.PRINT ->
                    _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.PRAGMA ->
                    _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.PASS ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.MINUS ->
                    _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.LPAR ->
                    _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.LET ->
                    _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.IF ->
                    _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.IDENTIFIER _v_5 ->
                    _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState665
                | Tokens.FOR ->
                    _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.DEBUG ->
                    _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.CONSTANT ->
                    _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.CASE ->
                    _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.ASSERT ->
                    _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
                | Tokens.END ->
                    let _v_6 =
                      let _endpos__0_ = _endpos_4 in
                      _menhir_action_234 _endpos__0_
                    in
                    _menhir_run_666 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_646 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_077 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_078 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_636 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_083 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_084 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_554 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_loop_limit -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_loop_limit (_menhir_stack, _, loop_limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _4, _1_inlined1, stmt_list) = ((), _endpos_1, (), (), (), _v) in
                let _v = _menhir_action_280 _1 _1_inlined1 _2 _4 _endpos__2_ _startpos__1_ expr loop_limit stmt_list in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_loop_limit (_menhir_stack, _, loop_limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _4, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, stmt_list) = ((), (), _endpos_0, _startpos, (), _v) in
                let _v = _menhir_action_281 _1 _1_inlined1 _4 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ expr loop_limit stmt_list in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_548 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_list1_catcher_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let (_1, _2, _3) = ((), (), _v) in
        let _v = _menhir_action_245 _1 _2 _3 in
        _menhir_goto_otherwise_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_goto_otherwise_opt : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_list1_catcher_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_list1_catcher_ (_menhir_stack, _, c) = _menhir_stack in
                let MenhirCell1_stmt_list (_menhir_stack, _, s, _) = _menhir_stack in
                let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, o) = ((), _endpos_0, (), (), (), _v) in
                let _v = _menhir_action_284 _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ c o s in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_list1_catcher_ (_menhir_stack, _, c) = _menhir_stack in
                let MenhirCell1_stmt_list (_menhir_stack, _, s, _) = _menhir_stack in
                let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, o) = ((), (), _endpos, _startpos, (), _v) in
                let _v = _menhir_action_285 _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ c o s in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_544 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, _4, stmt_list) = ((), (), _v) in
        let _v = _menhir_action_028 _1 _4 stmt_list ty in
        _menhir_goto_catcher _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_catcher : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_catcher (_menhir_stack, _menhir_s, _v) in
            _menhir_run_536 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.END | Tokens.OTHERWISE ->
            let x = _v in
            let _v = _menhir_action_225 x in
            _menhir_goto_list1_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_536 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState536, _v, _startpos_0, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos, _endpos) in
                let _menhir_s = MenhirState538 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.ARROW ->
                let _v =
                  let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos_0, _v) in
                  _menhir_action_333 _endpos_name_ _startpos_name_ name
                in
                _menhir_run_542 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState536 _tok
            | _ ->
                _eRR ())
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState536
        | _ ->
            _eRR ()
    
    and _menhir_run_542 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState543 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_list1_catcher_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState552 ->
            _menhir_run_553 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState535 ->
            _menhir_run_545 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_553 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_catcher -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_catcher (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_226 l x in
        _menhir_goto_list1_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_545 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_list1_catcher_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState547 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINTLN ->
                    _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let _v = _menhir_action_244 () in
            _menhir_goto_otherwise_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_541 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell0_COLON (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, _4, stmt_list) = ((), (), _v) in
        let _v = _menhir_action_029 _1 _4 stmt_list ty x in
        _menhir_goto_catcher _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_534 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_TRY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.CATCH ->
            let _menhir_s = MenhirState535 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_536 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_529 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_REPEAT as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNTIL ->
            let _menhir_s = MenhirState530 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_524 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _endpos__2_, _2) = ((), _endpos, _v) in
        let _v = _menhir_action_264 _1 _2 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_goto_s_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState518 ->
            _menhir_run_526 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState522 ->
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_526 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
                let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
                let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, s2) = ((), _endpos_1, (), (), (), _v) in
                let _v = _menhir_action_274 _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ e s1 s2 in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
                let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
                let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, s2) = ((), (), _endpos_0, _startpos, (), _v) in
                let _v = _menhir_action_275 _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ e s1 s2 in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_525 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_s2_, s2) = ((), (), _endpos, _v) in
        let _v = _menhir_action_262 _1 _3 _endpos_s2_ _startpos__1_ e s1 s2 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s2_ _v _menhir_s _tok
    
    and _menhir_run_522 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_519 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState522
        | Tokens.ELSE ->
            _menhir_run_523 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState522
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_263 _endpos__0_
            in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_519 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState519 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_523 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState523 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_518 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_519 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState518
        | Tokens.ELSE ->
            _menhir_run_523 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState518
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_263 _endpos__0_
            in
            _menhir_run_526 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_515 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_loop_limit -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_loop_limit (_menhir_stack, _, limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
                let MenhirCell1_direction (_menhir_stack, _, dir) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
                let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, body, _1_inlined1, _8) = ((), _endpos_1, (), (), _v, (), ()) in
                let _v = _menhir_action_282 _1 _1_inlined1 _2 _3 _8 _endpos__2_ _startpos__1_ body dir end_e index_name limit start_e in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_loop_limit (_menhir_stack, _, limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
                let MenhirCell1_direction (_menhir_stack, _, dir) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
                let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, body, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _8) = ((), (), _v, _endpos_0, _startpos, (), ()) in
                let _v = _menhir_action_283 _1 _1_inlined1 _3 _8 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ body dir end_e index_name limit start_e in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_508 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF, ttv_result) _menhir_cell1_list1_case_alt_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_list1_case_alt_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _2_inlined1, _1_inlined3, otherwise_stmt, _1_inlined2) = ((), _endpos_1, (), (), (), (), _v, ()) in
                let _v = _menhir_action_278 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr otherwise_stmt in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_list1_case_alt_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _2_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3, otherwise_stmt, _1_inlined2) = ((), (), (), _endpos_0, _startpos, (), _v, ()) in
                let _v = _menhir_action_279 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ expr otherwise_stmt in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined3_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_504 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_pattern_list (_menhir_stack, _, pattern) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, _endpos_stmt_, stmt) = ((), (), _endpos, _v) in
        let _v = _menhir_action_026 _1 _4 _endpos_stmt_ _startpos__1_ pattern stmt in
        _menhir_goto_case_alt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_case_alt : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_case_alt (_menhir_stack, _menhir_s, _v) in
            _menhir_run_454 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState513
        | Tokens.END | Tokens.OTHERWISE ->
            let x = _v in
            let _v = _menhir_action_223 x in
            _menhir_goto_list1_case_alt_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_454 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState454 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_040 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState040 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_052 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
            let _v = _menhir_action_250 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState055 ->
            _menhir_run_255 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState454 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_255 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState256 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_054 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_254 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_055 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState055 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_056 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState056 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_039 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState039 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_131 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState131 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_143 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState143
        | Tokens.LBRACE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState144
            | Tokens.REAL_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState144
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.MINUS ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_5 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState145
                | Tokens.REAL_LIT _v_6 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState145
                | Tokens.RBRACE ->
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_2, _endpos_desc_, _startpos_desc_, desc, _3, _endpos__4_, _4) = ((), _endpos, _startpos, _v, (), _endpos_7, ()) in
                    let _v = _menhir_action_202 _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc in
                    _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_desc_ _v _menhir_s _tok
                | Tokens.NOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.INT_LIT _v_8 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState145
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.IDENTIFIER _v_9 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState145
                | Tokens.BOOL_LIT _v_10 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState145
                | Tokens.BNOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.BITVECTOR_LIT _v_11 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 MenhirState145
                | Tokens.ARBITRARY ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | _ ->
                    _eRR ())
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.INT_LIT _v_12 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState144
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.IDENTIFIER _v_13 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState144
            | Tokens.BOOL_LIT _v_14 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState144
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.BITVECTOR_LIT _v_15 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState144
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_161 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_147 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.SHL | Tokens.SHR | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_116 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_148 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState148 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_149 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_2, _3, _endpos__4_, _4) = ((), (), _endpos_0, ()) in
            let _v = _menhir_action_157 _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_desc_ _v _menhir_s _tok
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | _ ->
            _eRR ()
    
    and _menhir_run_154 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_EQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState154 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_170 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState170 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_172 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState172 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_173 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState173 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_174 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState175 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_181 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState182 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_054 x in
            _menhir_goto_clist1_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_pattern_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState256 ->
            _menhir_run_257 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState454 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_251 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_257 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_pattern (_menhir_stack, _, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_068 _2 li x in
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_253 _endpos__3_ _startpos__1_ x in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_253 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_256 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_pattern_list _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_pattern_list : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState454 ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_262 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState173 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_455 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_pattern_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHERE ->
            let _menhir_s = MenhirState456 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            let _menhir_s = MenhirState503 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_262 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_257 x in
            _menhir_goto_pattern_set _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_pattern_set : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState038 ->
            _menhir_run_264 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState216 ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState454 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_264 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_pattern_set_, pattern_set) = ((), _endpos, _v) in
        let _v = _menhir_action_152 _2 _endpos_pattern_set_ _startpos_expr_ expr pattern_set in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_pattern_set_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_run_218 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_IN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_pattern_set_, pattern_set) = ((), _endpos, _v) in
        let _v = _menhir_action_197 _2 _endpos_pattern_set_ _startpos_expr_pattern_ expr_pattern pattern_set in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_pattern_set_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_178 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_255 _1 in
        _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_179 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, x, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_258 _1 _endpos__3_ _startpos__1_ x in
            _menhir_goto_pattern_set _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_251 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_pattern (_menhir_stack, _menhir_s, h, _startpos_h_, _) = _menhir_stack in
        let (_2, _endpos_t_, t) = ((), _endpos, _v) in
        let _v = _menhir_action_055 _2 h t in
        _menhir_goto_clist1_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_h_ _v _menhir_s _tok
    
    and _menhir_goto_list1_case_alt_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState513 ->
            _menhir_run_514 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState453 ->
            _menhir_run_505 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_514 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_case_alt -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_case_alt (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_224 l x in
        _menhir_goto_list1_case_alt_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_505 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _menhir_stack = MenhirCell1_list1_case_alt_ (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState507 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINTLN ->
                    _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, _1_inlined2) = ((), _endpos_1, (), (), _v, ()) in
                let _v = _menhir_action_276 _1 _1_inlined1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ expr in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_277 _1 _1_inlined1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ expr in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_462 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ARROW -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ARROW (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2, _, _) = _menhir_stack in
        let MenhirCell1_pattern_list (_menhir_stack, _, pattern) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, _1_inlined1, _endpos_stmt_, stmt) = ((), (), (), _endpos, _v) in
        let _v = _menhir_action_027 _1 _1_inlined1 _2 _4 _endpos_stmt_ _startpos__1_ pattern stmt in
        _menhir_goto_case_alt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_476 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_stmt -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_stmt (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_228 l x in
        _menhir_goto_list1_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _v _menhir_s _tok
    
    and _menhir_run_639 : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ARROW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState639 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_702 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BIARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState704 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_688 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState688) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState689
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState689
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_234 _endpos__0_
                in
                _menhir_run_690 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState688
        | _ ->
            _eRR ()
    
    and _menhir_run_652 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BIARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState654 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_633 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState633) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState634
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState634
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_234 _endpos__0_
                in
                _menhir_run_636 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState633
        | _ ->
            _eRR ()
    
    and _menhir_run_712 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | _ ->
            _eRR ()
    
    and _menhir_run_701 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState701
        | _ ->
            _eRR ()
    
    and _menhir_run_687 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | _ ->
            _eRR ()
    
    and _menhir_run_651 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState651
        | _ ->
            _eRR ()
    
    and _menhir_run_625 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState625
        | _ ->
            _eRR ()
    
    and _menhir_run_622 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_opt_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_opt_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_053 _2 h t in
        _menhir_goto_clist1_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_684 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.FUNC ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_1, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState686
                | Tokens.LPAR ->
                    let _v_2 = _menhir_action_246 () in
                    _menhir_run_687 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState686 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.ACCESSOR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_3, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState700
                | Tokens.LPAR ->
                    let _v_4 = _menhir_action_246 () in
                    _menhir_run_701 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState700 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_710 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState711
            | Tokens.LPAR ->
                let _v_1 = _menhir_action_246 () in
                _menhir_run_712 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState711 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_724 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_211 _1 in
        _menhir_goto_global_let_or_constant _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_725 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState725 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_562 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_563 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_731 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
            | Tokens.LPAR ->
                let _v_0 = _menhir_action_246 () in
                _menhir_run_733 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState732 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_058 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RDIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState058 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_031 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_POW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState031 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_060 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PLUS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState060 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_070 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_OR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState070 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_072 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_154 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | _ ->
            _eRR ()
    
    and _menhir_run_062 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MUL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState062 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_064 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MOD (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState064 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_075 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState075 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_077 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState077 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_025 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState025 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_083 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState083 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_038 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IN (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState038 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BNOT ->
            _menhir_run_217 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_217 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IN as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState217 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_089 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IMPL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState089 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_085 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_GT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState085 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_087 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState087 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_091 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_153 _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_ expr in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_expr_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | _ ->
            _eRR ()
    
    and _menhir_run_042 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState043 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_148 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_066 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIVRM (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState066 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_068 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState068 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_079 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState079 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_094 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState094 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_096 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BEQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState096 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_098 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BAND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState098 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_100 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState100 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_081 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState081 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_729 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_088 _1 _4 _endpos__2_ _startpos__1_ name ty x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState729
        | _ ->
            _eRR ()
    
    and _menhir_run_643 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | Tokens.BEGIN ->
            let MenhirCell1_RECURSELIMIT (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_260 _1 _2 in
            _menhir_goto_recurse_limit _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_recurse_limit : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState718 ->
            _menhir_run_719 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState693 ->
            _menhir_run_694 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState641 ->
            _menhir_run_644 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_694 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState695
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_234 _endpos__0_
            in
            _menhir_run_696 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_644 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState645
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState645
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_234 _endpos__0_
            in
            _menhir_run_646 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_567 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_option_as_ty_ (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_089 _1 _4 _endpos__2_ _startpos__1_ name ty x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState567
        | _ ->
            _eRR ()
    
    and _menhir_run_531 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.LOOPLIMIT ->
            _menhir_run_310 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState531
        | Tokens.SEMI_COLON ->
            let _v_0 = _menhir_action_231 () in
            _menhir_run_532 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_310 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState310 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_532 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_stmt_list (_menhir_stack, _, stmt_list, _) = _menhir_stack in
            let MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3, loop_limit) = ((), _endpos, (), _v) in
            let _v = _menhir_action_305 _1 _3 _endpos__2_ _startpos__1_ expr loop_limit stmt_list in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_520 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState520) in
            let _menhir_s = MenhirState521 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
        | _ ->
            _eRR ()
    
    and _menhir_run_499 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_setter_access, ttv_result) _menhir_cell1_slices as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_slices (_menhir_stack, _, desc_inlined1, _startpos_desc_inlined1_, _endpos_desc_inlined1_) = _menhir_stack in
            let MenhirCell1_setter_access (_menhir_stack, _, setter_access) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _4, rhs) = (_endpos_0, (), _v) in
            let _v = _menhir_action_294 _4 _endpos__2_ _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ desc desc_inlined1 rhs setter_access in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
        | _ ->
            _eRR ()
    
    and _menhir_run_495 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_setter_access, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_setter_access (_menhir_stack, _, setter_access) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _3, rhs) = (_endpos_0, (), _v) in
            let _v = _menhir_action_293 _3 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs setter_access in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
        | _ ->
            _eRR ()
    
    and _menhir_run_488 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET, ttv_result) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, _4, rhs) = (_endpos_0, (), (), _v) in
            let _v = _menhir_action_295 _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | _ ->
            _eRR ()
    
    and _menhir_run_479 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_lexpr (_menhir_stack, _menhir_s, le, _startpos_le_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, e) = (_endpos_0, (), _v) in
            let _v = _menhir_action_292 _2_inlined1 _endpos__2_ _startpos_le_ e le in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | _ ->
            _eRR ()
    
    and _menhir_run_472 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, local_decl_keyword_non_var, _startpos_local_decl_keyword_non_var_) = _menhir_stack in
            let (_endpos__2_, _4, x_inlined1) = (_endpos_0, (), _v) in
            let _v = _menhir_action_291 _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x x_inlined1 in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
        | _ ->
            _eRR ()
    
    and _menhir_run_468 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, local_decl_keyword_non_var, _startpos_local_decl_keyword_non_var_) = _menhir_stack in
            let (_endpos__2_, x, _4) = (_endpos_0, _v, ()) in
            let _v = _menhir_action_290 _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
        | _ ->
            _eRR ()
    
    and _menhir_run_460 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ASSERT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
            let _v = _menhir_action_289 _1 _endpos__2_ _startpos__1_ e in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | _ ->
            _eRR ()
    
    and _menhir_run_457 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_ARROW (_menhir_stack, MenhirState457) in
            let _menhir_s = MenhirState458 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | _ ->
            _eRR ()
    
    and _menhir_run_452 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_CASE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.OF ->
            let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState452) in
            let _menhir_s = MenhirState453 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_454 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
        | _ ->
            _eRR ()
    
    and _menhir_run_442 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.LOOPLIMIT ->
            _menhir_run_310 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
        | Tokens.DO ->
            let _v_0 = _menhir_action_231 () in
            _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState442 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_443 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loop_limit (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.DO ->
            let _menhir_s = MenhirState444 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_438 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.TO ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_menhir_s, _1) = (MenhirState438, ()) in
            let _v = _menhir_action_101 _1 in
            _menhir_goto_direction _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.DOWNTO ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_menhir_s, _1) = (MenhirState438, ()) in
            let _v = _menhir_action_102 _1 in
            _menhir_goto_direction _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | _ ->
            _eRR ()
    
    and _menhir_goto_direction : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_direction (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v_0 ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState441
        | Tokens.REAL_LIT _v_1 ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState441
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState441
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState441
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState441
        | Tokens.INT_LIT _v_2 ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState441
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState441
        | Tokens.IDENTIFIER _v_3 ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState441
        | Tokens.BOOL_LIT _v_4 ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState441
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState441
        | Tokens.BITVECTOR_LIT _v_5 ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState441
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState441
        | _ ->
            _eRR ()
    
    and _menhir_run_413 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState413) in
            let _menhir_s = MenhirState414 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | _ ->
            _eRR ()
    
    and _menhir_run_394 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RRBRACKET (_menhir_stack, MenhirState394, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LLBRACKET ->
                _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
            | Tokens.DOT ->
                _menhir_run_396 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
            | Tokens.COMMA | Tokens.EQ | Tokens.LBRACKET | Tokens.RPAR ->
                let _v_1 = _menhir_action_003 () in
                _menhir_run_399 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | _ ->
            _eRR ()
    
    and _menhir_run_371 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_RETURN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
        | Tokens.SEMI_COLON ->
            let x = _v in
            let _v = _menhir_action_241 x in
            _menhir_goto_option_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_366 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_THROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
            let _v = _menhir_action_306 _1 _endpos__2_ _startpos__1_ e in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | _ ->
            _eRR ()
    
    and _menhir_run_335 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Tokens.SEMI_COLON ->
            let MenhirCell1_EQ (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_243 _1 _2 in
            _menhir_goto_option_eq_expr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_option_eq_expr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState338 ->
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState333 ->
            _menhir_run_336 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_354 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos__2_, e) = ((), _endpos, _v) in
        let _v = _menhir_action_298 _1 _endpos__2_ _startpos__1_ e ldi x in
        _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_run_336 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos__2_, e) = ((), _endpos, _v) in
        let _v = _menhir_action_297 _1 _endpos__2_ _startpos__1_ e ldi in
        _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_run_311 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DO | Tokens.SEMI_COLON ->
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_232 _1 _2 in
            _menhir_goto_loop_limit _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_loop_limit : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState531 ->
            _menhir_run_532 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState442 ->
            _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState309 ->
            _menhir_run_312 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_312 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loop_limit (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.DO ->
            let _menhir_s = MenhirState313 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_309 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHILE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LOOPLIMIT ->
            _menhir_run_310 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DO ->
            let _v_0 = _menhir_action_231 () in
            _menhir_run_312 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState309 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_308 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_143 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_302 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_156 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState302) in
            let _menhir_s = MenhirState304 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | _ ->
            _eRR ()
    
    and _menhir_run_300 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.ELSIF ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.ELSE ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | _ ->
            _eRR ()
    
    and _menhir_run_135 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState135 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_139 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState139 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_298 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState298) in
            let _menhir_s = MenhirState299 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | _ ->
            _eRR ()
    
    and _menhir_run_295 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_141 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_282 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SLICING as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.COMMA | Tokens.RBRACE ->
            let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_215 _2 e1 e2 in
            _menhir_goto_int_constraint _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_int_constraint : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_int_constraint (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState279 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_050 x in
            _menhir_goto_clist1_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_clist1_int_constraint_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState020 ->
            _menhir_run_284 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState279 ->
            _menhir_run_283 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_284 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_069 x in
        _menhir_goto_constraint_kind _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_283 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_int_constraint -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_int_constraint (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_051 _2 h t in
        _menhir_goto_clist1_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_280 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_SLICING (_menhir_stack, MenhirState280) in
            let _menhir_s = MenhirState281 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.COMMA | Tokens.RBRACE ->
            let expr = _v in
            let _v = _menhir_action_214 expr in
            _menhir_goto_int_constraint _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_273 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_268 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_slice : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_slice (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState266 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACKET ->
            let x = _v in
            let _v = _menhir_action_056 x in
            _menhir_goto_clist1_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_clist1_slice_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState033 ->
            _menhir_run_275 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState266 ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_275 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_272 x in
        _menhir_goto_slices _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_slices : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState493 ->
            _menhir_run_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState400 ->
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState258 ->
            _menhir_run_250 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState183 ->
            _menhir_run_250 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState125 ->
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState107 ->
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState749 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState729 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState643 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState567 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState531 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState413 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState520 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState452 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState457 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState499 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState495 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState488 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState479 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState472 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState468 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState460 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState442 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState438 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState394 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState371 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState366 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState335 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState309 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState311 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState308 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState302 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState298 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState300 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState295 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState280 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState282 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState024 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState026 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState028 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState030 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState032 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState267 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState273 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState271 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState269 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState035 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState037 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState254 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState249 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState244 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState242 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState240 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState238 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState236 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState234 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState227 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState224 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState222 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState220 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState215 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState212 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState210 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState208 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState206 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState204 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState202 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState199 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState197 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState195 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState193 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState191 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState189 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState187 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState185 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState171 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState157 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState155 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState132 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState134 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState136 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState138 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState140 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState057 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState105 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState117 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState099 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState097 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState095 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState090 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState093 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState074 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState088 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState086 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState084 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState078 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState082 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState080 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState076 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState071 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState061 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState069 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState067 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState065 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState063 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState059 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState053 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState041 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_497 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_setter_access as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState498 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_401 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_access -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_access (_menhir_stack, _, access) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_endpos_desc_inlined1_, _startpos_desc_inlined1_, desc_inlined1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_016 _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ access desc desc_inlined1 in
        _menhir_goto_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_250 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_endpos_slices_, slices) = (_endpos, _v) in
        let _v = _menhir_action_191 _endpos_slices_ _startpos_e_ e slices in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_slices_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_111 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos_1, _endpos_2) in
                _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState112
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos_1, _endpos_2) in
                _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState112
            | Tokens.COMMA | Tokens.RBRACE ->
                let (s, x) = (_v, _v_0) in
                let _v = _menhir_action_017 s x in
                _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_107 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState107 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RBRACE ->
            let _v = _menhir_action_315 () in
            _menhir_goto_tclist0_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist0_bitfield_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_020 x in
        _menhir_goto_bitfields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_goto_bitfields : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState106 ->
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState112 ->
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_128 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_022 _1 in
        _menhir_goto_bitfields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
    
    and _menhir_goto_bitfields_opt : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_bitfields_opt_, bitfields_opt) = ((), _endpos, _v) in
        let _v = _menhir_action_331 _1 _endpos_bitfields_opt_ _startpos__1_ bitfields_opt x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_bitfields_opt_ _v _menhir_s _tok
    
    and _menhir_run_122 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slices _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_slices (_menhir_stack, _menhir_s, s, _, _) = _menhir_stack in
        let bf = _v in
        let _v = _menhir_action_018 bf s x in
        _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_bitfield : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _menhir_stack = MenhirCell1_bitfield (_menhir_stack, _menhir_s, _v) in
                _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState125
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_321 x x_inlined1 in
                _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_320 x in
            _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_bitfield_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState125 ->
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState107 ->
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_126 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_bitfield -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_bitfield (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_322 _2 h t in
        _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_108 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_316 _1 in
        _menhir_goto_tclist0_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_050 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_endpos_slices_, slices) = (_endpos, _v) in
        let _v = _menhir_action_146 _endpos_slices_ _startpos_e_ e slices in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_slices_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_274 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slice -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_slice (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_057 _2 h t in
        _menhir_goto_clist1_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_271 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_PLUS_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_269 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_269 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_STAR_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_STAR_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_271 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_267 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.STAR_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_STAR_COLON (_menhir_stack, MenhirState267) in
            let _menhir_s = MenhirState268 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.PLUS_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_PLUS_COLON (_menhir_stack, MenhirState267) in
            let _menhir_s = MenhirState270 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState267 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _menhir_s = MenhirState272 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.COMMA | Tokens.RBRACKET ->
            let expr = _v in
            let _v = _menhir_action_267 expr in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_254 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_186 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_249 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_AND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_162 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_244 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BAND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BAND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_163 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_242 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_165 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_240 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_164 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_238 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_COLON_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_COLON_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_185 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_236 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_166 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_234 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DIVRM as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIVRM (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_167 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_227 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_EQ_OP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_EQ_OP (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_169 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_224 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_172 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_222 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_GT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_171 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_220 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_IMPL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_IMPL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_173 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_215 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_175 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_212 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos__4_, _4, e2) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_192 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | _ ->
            _eRR ()
    
    and _menhir_run_210 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_LT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_174 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_208 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_177 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_206 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MOD (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_178 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_204 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MUL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MUL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_179 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_202 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_NEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_NEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_170 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_199 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_OR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_180 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_197 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_PLUS (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_176 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_195 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_POW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_POW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_184 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_193 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_RDIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_RDIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_181 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_191 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SHL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_182 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_189 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SHR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_183 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_187 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SLICING as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_249 _2 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_185 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_XOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_XOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_168 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_171 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_252 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_157 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState157) in
            let _menhir_s = MenhirState158 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.RBRACE | Tokens.RPAR | Tokens.SEMI_COLON ->
            let x = _v in
            let _v = _menhir_action_046 x in
            _menhir_goto_clist1_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_expr_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState346 ->
            _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_305 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState610 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState446 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState384 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState379 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState374 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState349 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState343 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState416 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_347 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_clist1_expr_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_0 ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState349
                | Tokens.REAL_LIT _v_1 ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState349
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState349
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState349
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState349
                | Tokens.INT_LIT _v_2 ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState349
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState349
                | Tokens.IDENTIFIER _v_3 ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState349
                | Tokens.BOOL_LIT _v_4 ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState349
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState349
                | Tokens.BITVECTOR_LIT _v_5 ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState349
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState349
                | Tokens.RPAR ->
                    let _v_6 = _menhir_action_030 () in
                    _menhir_run_350 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _3, _endpos__5_, _5, params) = ((), (), _endpos, (), _v) in
                let _v = _menhir_action_113 _2 _3 _5 name params in
                _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _startpos_name_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_350 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist1_expr_ (_menhir_stack, _, params) = _menhir_stack in
            let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_2, x, _3, _endpos__3_inlined1_, _5) = ((), _v, (), _endpos, ()) in
            let _v = _menhir_action_114 _2 _3 _5 name params x in
            _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_elided_param_call : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState471 ->
            _menhir_run_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState339 ->
            _menhir_run_352 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_474 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
            let MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, ldk, _startpos_ldk_) = _menhir_stack in
            let (_endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = (_endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_296 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ _startpos_ldk_ desc ldk lhs ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_352 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty, ttv_result) _menhir_cell1_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_300 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_305 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_067 _2 li x in
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_159 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_165 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_031 _1 in
        _menhir_goto_clist0_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist0_expr_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState610 ->
            _menhir_run_611 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState446 ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState384 ->
            _menhir_run_385 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState379 ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState374 ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState349 ->
            _menhir_run_350 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState343 ->
            _menhir_run_344 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState010 ->
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState164 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_344 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_2, x, _3, _endpos__3_inlined1_) = ((), _v, (), _endpos) in
            let _v = _menhir_action_112 _2 _3 name x in
            _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_296 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_023 name x in
            _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_call : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState754 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState720 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState714 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState695 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState689 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState677 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState672 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState665 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState645 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState363 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState547 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState543 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState540 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState372 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState454 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState748 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState728 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState642 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState610 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState566 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState530 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState437 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState441 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState451 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState498 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState471 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState467 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState459 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState446 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState416 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState393 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState384 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState379 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState374 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState368 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState339 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState349 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState343 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState334 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState310 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState279 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState025 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState029 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState031 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState033 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState266 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState268 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState248 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState243 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState241 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState239 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState237 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState235 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState233 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState225 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState223 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState219 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState214 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState211 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState209 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState207 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState205 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState203 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState200 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState198 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState194 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState192 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState190 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState188 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState116 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState052 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_481 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__2_, _startpos_call_, call) = (_endpos_0, _startpos, _v) in
            let _v = _menhir_action_288 _endpos__2_ _startpos_call_ call in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_call (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, MenhirState481) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState484 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_490 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | Tokens.EQ | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_call (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v_4 = _menhir_action_265 () in
            _menhir_run_493 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState481 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_490 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, MenhirState490) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_490 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | Tokens.EQ | Tokens.LBRACKET ->
            let _v_1 = _menhir_action_265 () in
            _menhir_run_492 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_492 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, t) = ((), _v) in
        let _v = _menhir_action_266 _1 _endpos_desc_ _startpos_desc_ desc t in
        _menhir_goto_setter_access _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_setter_access : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState481 ->
            _menhir_run_493 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState490 ->
            _menhir_run_492 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_493 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_call as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_setter_access (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState493
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState493) in
            let _menhir_s = MenhirState494 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_252 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_call_, _startpos_call_, call) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_190 _endpos_call_ _startpos_call_ call in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_call_ _startpos_call_ _v _menhir_s _tok
    
    and _menhir_run_051 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_call_, _startpos_call_, call) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_145 _endpos_call_ _startpos_call_ call in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_call_ _startpos_call_ _v _menhir_s _tok
    
    and _menhir_run_166 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist1_expr_ (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (x_inlined1, _endpos__3_inlined1_) = (_v, _endpos) in
            let _v = _menhir_action_025 name x x_inlined1 in
            _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_162 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_clist1_expr_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_0 ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState164
                | Tokens.REAL_LIT _v_1 ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState164
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.INT_LIT _v_2 ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState164
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.IDENTIFIER _v_3 ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState164
                | Tokens.BOOL_LIT _v_4 ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState164
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.BITVECTOR_LIT _v_5 ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState164
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.RPAR ->
                    let _v_6 = _menhir_action_030 () in
                    _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
                let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (x, _endpos__3_) = (_v, _endpos) in
                let _v = _menhir_action_024 name x in
                _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_159 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_047 _2 h t in
        _menhir_goto_clist1_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_155 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.COMMA | Tokens.RBRACE ->
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let y = _v in
            let _v = _menhir_action_204 x y in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_field_assign (_menhir_stack, _menhir_s, _v) in
                let _menhir_s = MenhirState152 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_s = MenhirState153 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.EQ ->
                        _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.RBRACE ->
                let x = _v in
                let _v = _menhir_action_048 x in
                _menhir_goto_clist1_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _menhir_fail ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_field_assign_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState144 ->
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState341 ->
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState148 ->
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState152 ->
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_168 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_203 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_160 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_158 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_156 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_field_assign -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_field_assign (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_049 _2 h t in
        _menhir_goto_clist1_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_140 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.ARROW | Tokens.BEGIN | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _endpos__2_, _2) = ((), _endpos, _v) in
            let _v = _menhir_action_109 _1 _2 in
            _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_e_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState300 ->
            _menhir_run_301 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState134 ->
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState138 ->
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_301 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_144 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_142 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_189 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_141 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, c, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e2_, e2) = ((), (), _endpos, _v) in
        let _v = _menhir_action_110 _1 _3 _endpos_e2_ _startpos__1_ c e1 e2 in
        _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _v _menhir_s _tok
    
    and _menhir_run_138 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.ELSIF ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.ELSE ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | _ ->
            _eRR ()
    
    and _menhir_run_136 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState136) in
            let _menhir_s = MenhirState137 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | _ ->
            _eRR ()
    
    and _menhir_run_134 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.ELSIF ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.ELSE ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | _ ->
            _eRR ()
    
    and _menhir_run_132 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState132) in
            let _menhir_s = MenhirState133 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | _ ->
            _eRR ()
    
    and _menhir_run_117 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ARRAY as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.RRBRACKET ->
            let _menhir_s = MenhirState117 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RRBRACKET (_menhir_stack, _menhir_s, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.OF ->
                let _menhir_s = MenhirState119 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | _ ->
            _eRR ()
    
    and _menhir_run_105 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.RPAR ->
            let _menhir_s = MenhirState105 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
            let _menhir_s = MenhirState106 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
                let _v = _menhir_action_021 () in
                _menhir_goto_bitfields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | _ ->
            _eRR ()
    
    and _menhir_run_099 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BAND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BAND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_118 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_097 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_120 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_095 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_119 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_093 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_EQ_OP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_EQ_OP (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_124 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_090 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IMPL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_IMPL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_128 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_088 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_127 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_086 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_126 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_084 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_130 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_082 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_AND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_117 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_080 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_COLON_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_140 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_078 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_129 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_076 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_132 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_074 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_NEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_NEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_125 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_071 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_OR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_135 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_069 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_121 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_067 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIVRM as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIVRM (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_122 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_065 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MOD (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_133 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_063 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MUL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MUL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_134 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_061 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_PLUS (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_131 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_059 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RDIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_RDIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_136 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_057 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_251 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_053 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_187 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_041 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_188 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_037 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_137 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_035 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (desc, e) = ((), _v) in
            let _v = _menhir_action_270 _endpos_desc_ _startpos_desc_ desc e in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_032 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_POW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_POW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_139 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_030 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_138 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_028 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_XOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_XOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_123 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_026 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos__4_, _4, e2) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_147 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | _ ->
            _eRR ()
    
    and _menhir_run_024 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_142 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist0_ty_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_332 _endpos__3_ _startpos__1_ x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_333 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState333) in
            let _menhir_s = MenhirState334 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState333
        | Tokens.SEMI_COLON ->
            let _v_6 = _menhir_action_242 () in
            _menhir_run_336 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | _ ->
            _eRR ()
    
    and _menhir_run_329 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState330 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_038 _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_clist1_annotated_IDENTIFIER__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_annotated_IDENTIFIER__ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState328 ->
            _menhir_run_332 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState330 ->
            _menhir_run_331 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_332 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_063 _2 _endpos_desc_ _startpos_desc_ desc li in
        let _menhir_stack = MenhirCell1_clist2_annotated_IDENTIFIER__ (_menhir_stack, _menhir_s, _v) in
        _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState356
    
    and _menhir_run_331 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_039 _2 _endpos_desc_ _startpos_desc_ desc t in
        _menhir_goto_clist1_annotated_IDENTIFIER__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_693 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_642 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState693
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_259 () in
            _menhir_run_694 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState693
        | _ ->
            _eRR ()
    
    and _menhir_run_641 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_642 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState641
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_259 () in
            _menhir_run_644 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState641
        | _ ->
            _eRR ()
    
    and _menhir_run_606 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_335 _1 in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_539 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState540 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_294 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ARBITRARY _menhir_cell0_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_COLON (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_155 _1 _2 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_288 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState289 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_058 x in
            _menhir_goto_clist1_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_ty_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState018 ->
            _menhir_run_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState289 ->
            _menhir_run_290 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_291 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_033 _1 in
        _menhir_goto_clist0_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_290 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _menhir_s, h, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_059 _2 h t in
        _menhir_goto_clist1_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_246 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_195 _2 _endpos_ty_ _startpos_expr_pattern_ expr_pattern ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_176 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ARBITRARY _menhir_cell0_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_COLON (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_200 _1 _2 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_129 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_150 _2 _endpos_ty_ _startpos_expr_ expr ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_run_121 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COLON (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
        let (_1, _2) = ((), _v) in
        let _v = _menhir_action_014 _1 _2 in
        _menhir_goto_as_ty _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_as_ty : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState746 ->
            _menhir_run_751 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState736 ->
            _menhir_run_737 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState726 ->
            _menhir_run_727 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState704 ->
            _menhir_run_705 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState654 ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState618 ->
            _menhir_run_619 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState579 ->
            _menhir_run_580 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState564 ->
            _menhir_run_569 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState466 ->
            _menhir_run_470 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState356 ->
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState333 ->
            _menhir_run_338 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_751 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let x = _v in
        let _v = _menhir_action_239 x in
        _menhir_goto_option_as_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_option_as_ty_ : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState746 ->
            _menhir_run_747 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState564 ->
            _menhir_run_565 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_737 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState738 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_657 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.GETTER ->
                _menhir_run_669 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_657 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_SETTER (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.IDENTIFIER _v ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState657
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
        | Tokens.END ->
            let _v =
              let _endpos__0_ = _endpos in
              _menhir_action_234 _endpos__0_
            in
            _menhir_run_658 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState657 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_669 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_GETTER (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.IDENTIFIER _v ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState669
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
        | Tokens.END ->
            let _v =
              let _endpos__0_ = _endpos in
              _menhir_action_234 _endpos__0_
            in
            _menhir_run_670 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState669 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_727 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState728 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_705 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState706 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_657 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.GETTER ->
                _menhir_run_669 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_655 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState656 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_657 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.GETTER ->
                _menhir_run_669 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_619 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let x_inlined1 = _v in
        let _v = _menhir_action_237 x x_inlined1 in
        _menhir_goto_opt_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_580 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let y = _v in
        let _v = _menhir_action_340 x y in
        _menhir_goto_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_typed_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState628 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState626 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState582 ->
            _menhir_run_581 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState576 ->
            _menhir_run_581 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_627 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState628 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_579 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_060 x in
            _menhir_goto_clist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState626 ->
            _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState628 ->
            _menhir_run_629 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_630 : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_035 _1 in
        _menhir_goto_clist0_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_629 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_061 _2 h t in
        _menhir_goto_clist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_581 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, _v) in
                _menhir_run_579 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState582
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_324 x x_inlined1 in
                _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_323 x in
            _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState576 ->
            _menhir_run_584 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState582 ->
            _menhir_run_583 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_584 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_206 x in
        _menhir_goto_fields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_583 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_325 _2 h t in
        _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_569 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_090 _1 _endpos__2_ _startpos__1_ name x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.EQ ->
            let x = _v in
            let _v = _menhir_action_239 x in
            _menhir_goto_option_as_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_470 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState471 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_340 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_340 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
        | Tokens.LBRACE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState341
            | Tokens.REAL_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState341
            | Tokens.RBRACE ->
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                    let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState341, _endpos_3) in
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING_LIT _v_5 ->
                        _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState343
                    | Tokens.REAL_LIT _v_6 ->
                        _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState343
                    | Tokens.NOT ->
                        _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState343
                    | Tokens.MINUS ->
                        _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState343
                    | Tokens.LPAR ->
                        _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState343
                    | Tokens.INT_LIT _v_7 ->
                        _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState343
                    | Tokens.IF ->
                        _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState343
                    | Tokens.IDENTIFIER _v_8 ->
                        _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState343
                    | Tokens.BOOL_LIT _v_9 ->
                        _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState343
                    | Tokens.BNOT ->
                        _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState343
                    | Tokens.BITVECTOR_LIT _v_10 ->
                        _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState343
                    | Tokens.ARBITRARY ->
                        _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState343
                    | Tokens.RPAR ->
                        let _v_11 = _menhir_action_030 () in
                        _menhir_run_344 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 _tok
                    | _ ->
                        _eRR ())
                | Tokens.SEMI_COLON ->
                    let (_2, _startpos_name_, name, _endpos__3_, _3) = ((), _startpos, _v, _endpos_3, ()) in
                    let _v = _menhir_action_111 _2 _3 name in
                    _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
            | Tokens.INT_LIT _v_12 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState341
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
            | Tokens.IDENTIFIER _v_13 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState341
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState341) in
                let _menhir_s = MenhirState346 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_20 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20 MenhirState341
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
            | Tokens.BITVECTOR_LIT _v_21 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_21 MenhirState341
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState340, _startpos_0) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_116 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_357 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_clist2_annotated_IDENTIFIER__ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_clist2_annotated_IDENTIFIER__ (_menhir_stack, _, _2_inlined1) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, as_ty) = ((), _endpos, _v) in
            let _v = _menhir_action_299 _1 _2_inlined1 _endpos__2_ _startpos__1_ as_ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_338 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState338) in
            let _menhir_s = MenhirState339 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_340 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SEMI_COLON ->
            let _v_6 = _menhir_action_242 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | _ ->
            _eRR ()
    
    and _menhir_run_123 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slices _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_slices (_menhir_stack, _menhir_s, s, _, _) = _menhir_stack in
        let ty = _v in
        let _v = _menhir_action_019 s ty x in
        _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_120 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_ARRAY, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RRBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RRBRACKET (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_t_, t, _4, _5) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_334 _1 _2 _4 _5 _endpos_t_ _startpos__1_ e t in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s _tok
    
    and _menhir_run_186 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SLICING (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState186 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_188 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState188 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_190 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState190 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_192 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RDIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState192 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_194 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_POW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState194 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_196 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PLUS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState196 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_198 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_OR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState198 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_200 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_199 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | _ ->
            _eRR ()
    
    and _menhir_run_203 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MUL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState203 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_205 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MOD (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState205 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_207 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState207 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_209 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState209 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_211 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState211 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_214 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState214 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_216 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IN (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState216 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BNOT ->
            _menhir_run_217 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_219 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IMPL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState219 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_221 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_GT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState221 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_223 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState223 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_225 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_198 _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_expr_pattern_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | _ ->
            _eRR ()
    
    and _menhir_run_228 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState229 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_193 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_233 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIVRM (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState233 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_235 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState235 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_237 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState237 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_239 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState239 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_241 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BEQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState241 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_243 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BAND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState243 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_245 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState245 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_248 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState248 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_183 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_186 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_221 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_225 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_228 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_233 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_235 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_237 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_239 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_241 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_243 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_245 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_248 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_248 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_023 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_value_, _startpos_value_, value) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_115 _endpos_value_ _startpos_value_ value in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_value_ _startpos_value_ _v _menhir_s _tok
    
    let _menhir_run_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState000 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    let _menhir_run_560 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_561 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.TYPE ->
            _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.PRAGMA ->
            _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.LET ->
            _menhir_run_613 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.IMPLEMENTATION ->
            _menhir_run_614 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.IMPDEF ->
            _menhir_run_684 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.FUNC ->
            _menhir_run_710 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.CONSTANT ->
            _menhir_run_724 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.CONFIG ->
            _menhir_run_725 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.ACCESSOR ->
            _menhir_run_731 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState560
        | Tokens.EOF ->
            let _v = _menhir_action_221 () in
            _menhir_run_743 _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_754 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState754 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_383 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_415 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
  end
  
  let stmts =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_stmts v = _menhir_run_754 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let spec =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_spec v = _menhir_run_560 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let opn =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_opn v = _menhir_run_000 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
end
